@@ -93,10 +93,10 @@ void PASTEMAC(ch,varname) \
 	} \
 \
 	/* If beta is zero, use setv. Otherwise, scale by beta. */ \
-	if ( PASTEMAC(ch,eq0)( *beta ) ) \
+	if ( bli_teq0s( ch, *beta ) ) \
 	{ \
 		/* y = 0; */ \
-		PASTEMAC2(ch,setv,BLIS_TAPI_EX_SUF) \
+		PASTEMAC(ch,setv,BLIS_TAPI_EX_SUF) \
 		( \
 		  BLIS_NO_CONJUGATE, \
 		  m, \
@@ -109,7 +109,7 @@ void PASTEMAC(ch,varname) \
 	else \
 	{ \
 		/* y = beta * y; */ \
-		PASTEMAC2(ch,scalv,BLIS_TAPI_EX_SUF) \
+		PASTEMAC(ch,scalv,BLIS_TAPI_EX_SUF) \
 		( \
 		  BLIS_NO_CONJUGATE, \
 		  m, \
@@ -136,8 +136,8 @@ void PASTEMAC(ch,varname) \
 		psi1     = y + (i  )*incy; \
 \
         /* Apply conjx to chi1 and and scale by alpha. */ \
-        PASTEMAC(ch,copycjs)( conjx, *chi1, conjx_chi1 ); \
-        PASTEMAC(ch,scal2s)( *alpha, conjx_chi1, alpha_chi1 ); \
+        bli_tcopycjs( ch,ch, conjx, *chi1, conjx_chi1 ); \
+        bli_tscal2s( ch,ch,ch,ch, *alpha, conjx_chi1, alpha_chi1 ); \
 \
 		/* psi1 = psi1 + alpha * a10t * x0; */ \
 		kfp_dv \
@@ -169,12 +169,12 @@ void PASTEMAC(ch,varname) \
 \
 		/* For hemv, explicitly set the imaginary component of alpha11 to
 		   zero. */ \
-		PASTEMAC(ch,copycjs)( conja, *alpha11, alpha11_temp ); \
+		bli_tcopycjs( ch,ch, conja, *alpha11, alpha11_temp ); \
 		if ( bli_is_conj( conjh ) ) \
-			PASTEMAC(ch,seti0s)( alpha11_temp ); \
+			bli_tseti0s( ch, alpha11_temp ); \
 \
 		/* psi1 = psi1 + alpha * alpha11 * chi1; */ \
-		PASTEMAC(ch,axpys)( alpha_chi1, alpha11_temp, *psi1 ); \
+		bli_taxpys( ch,ch,ch,ch, alpha_chi1, alpha11_temp, *psi1 ); \
 	} \
 }
 
