@@ -33,13 +33,12 @@
 
 */
 
+#include "bli_l3_util.h"
 #include "bli_l3_thrinfo.h"
 #include "bli_l3_decor.h"
 #include "bli_l3_sup_decor.h"
 
-#include "bli_l3_cntl.h"
 #include "bli_l3_check.h"
-#include "bli_l3_int.h"
 #include "bli_l3_packab.h"
 
 // Define function types.
@@ -47,10 +46,8 @@
 #include "bli_l3_oft.h"
 #include "bli_l3_oft_var.h"
 
-#include "bli_l3_blocksize.h"
-#include "bli_l3_direct.h"
+#include "bli_l3_int.h"
 #include "bli_l3_prune.h"
-#include "bli_l3_schema.h"
 
 // Prototype object APIs (basic and expert).
 #include "bli_l3_oapi.h"
@@ -86,9 +83,6 @@
 
 // Operation-specific headers.
 #include "bli_gemm.h"
-#include "bli_hemm.h"
-#include "bli_symm.h"
 #include "bli_trmm.h"
-#include "bli_trmm3.h"
 #include "bli_trsm.h"
 #include "bli_gemmt.h"
