@@ -6,6 +6,7 @@
 
    Copyright (C) 2014, The University of Texas at Austin
    Copyright (C) 2018 - 2019, Advanced Micro Devices, Inc.
+   Copyright (C) 2024, Southern Methodist University
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are
@@ -62,56 +63,40 @@ thrinfo_t* bli_l3_thrinfo_create
 
 void bli_l3_thrinfo_grow
      (
-             thrinfo_t*  thread_par,
+             thrinfo_t*  thread,
        const rntm_t*     rntm,
        const cntl_t*     cntl
      )
 {
-	const cntl_t* sub_prenode = bli_cntl_sub_prenode( cntl );
-	const cntl_t* sub_node    = bli_cntl_sub_node( cntl );
-	const bszid_t bszid       = bli_cntl_bszid( cntl );
-	const dim_t   n_way       = bli_rntm_ways_for( bszid, rntm );
-
-	thrinfo_t* thread_cur = bli_thrinfo_split( n_way, thread_par );
-	bli_thrinfo_set_sub_node( thread_cur, thread_par );
-
-	if ( bszid == BLIS_NO_PART )
+	// For leaf nodes, create one more node in the thread control tree
+	// which splits the remianing threads into single-thread teams.
+	if ( bli_cntl_is_leaf( cntl ) )
 	{
-		// A hack: the packing code needs a thread communicator which represents
-		// a group of single-member thread teams working cooperatively However,
-		// the "normal" packm thrinfo_t node has a single team of multiple
-		// threads. Our solution (for now) is to create a sub-prenode on the
-		// thrinfo_t tree which splits this single team into multiple
-		// single-member thread teams.
-		const dim_t n_threads = bli_thrinfo_num_threads( thread_par );
-		thrinfo_t* thread_pre = bli_thrinfo_split( n_threads, thread_par );
-		bli_thrinfo_set_sub_prenode( thread_pre, thread_par );
-	}
-	else if ( sub_prenode != NULL )
-	{
-		// A pre-node is only used in the IC loop of trsm. In this case,
-		// we cannot actually thread in the m dimension due to data dependencies
-		// and so all parallelism must be moved down to the JR loop.
-		rntm_t rntm_l = *rntm;
-		const dim_t ic_nway = bli_rntm_ic_ways( &rntm_l );
-		const dim_t jr_nway = bli_rntm_jr_ways( &rntm_l );
-		bli_rntm_set_ic_ways_only(               1, &rntm_l );
-		bli_rntm_set_jr_ways_only( ic_nway*jr_nway, &rntm_l );
+		dim_t      n_way      = bli_thrinfo_num_threads( thread );
+		thrinfo_t* thread_sub = bli_thrinfo_split( n_way, thread );
 
-		// Use thread_pre instead of thread_cur since we *don't* want to do any
-		// parallelism at this level. So the thread_pre node gets attached to
-		// thread_par and not thread_cur! This results in a split "one level
-		// higher" than in the corresponding cntl_t tree. This is intentional
-		// since two different thrinfo_t nodes will be used at the cntl_t node
-		// for trsm blocked variant 1 (one for trsm, one for gemm).
-		thrinfo_t* thread_pre = bli_thrinfo_split( 1, thread_par );
-		bli_thrinfo_set_sub_prenode( thread_pre, thread_par );
-		bli_l3_thrinfo_grow( thread_pre, &rntm_l, sub_prenode );
+		bli_thrinfo_attach_sub_node( thread_sub, thread );
+
+		return;
 	}
 
-	if ( sub_node != NULL )
+	// Create a thread control tree sub-node for each non-NULL control tree
+	// sub-node. Note that the "ways" encoded in the control tree for each
+	// sub-node control parallelism for the parent node, not the sub-node. This
+	// is necessary because some nodes need to parallelize differently when
+	// calling different sub-nodes (e.g. the ic loop of trsm_l).
+	for ( dim_t i = 0; i < BLIS_MAX_SUB_NODES; i++ )
 	{
-		bli_l3_thrinfo_grow( thread_cur, rntm, sub_node );
+		const cntl_t* sub_node = bli_cntl_sub_node( i, cntl );
+		if ( sub_node == NULL )
+			return;
+
+		dim_t      ways       = bli_cntl_ways( i, cntl );
+		dim_t      n_way      = bli_rntm_total_ways_for( ways, rntm );
+		thrinfo_t* thread_sub = bli_thrinfo_split( n_way, thread );
+
+		bli_thrinfo_attach_sub_node( thread_sub, thread );
+		bli_l3_thrinfo_grow( thread_sub, rntm, sub_node );
 	}
 }
 
@@ -148,22 +133,13 @@ thrinfo_t* bli_l3_sup_thrinfo_create
 	thrinfo_t* thread_jr = bli_thrinfo_split( n_way_jr, thread_pa );
 	thrinfo_t* thread_ir = bli_thrinfo_split( n_way_ir, thread_jr );
 
-	const dim_t n_way_pb = bli_thrinfo_num_threads( thread_pb );
-	const dim_t n_way_pa = bli_thrinfo_num_threads( thread_pa );
-
-	// Create and set the prenodes for the packb and packa thrinfo_t nodes.
-	thrinfo_t* thread_pb_single = bli_thrinfo_split( n_way_pb, thread_pb );
-	thrinfo_t* thread_pa_single = bli_thrinfo_split( n_way_pa, thread_pa );
-	bli_thrinfo_set_sub_prenode( thread_pb_single, thread_pb );
-	bli_thrinfo_set_sub_prenode( thread_pa_single, thread_pa );
-
-	bli_thrinfo_set_sub_node( thread_jc,      root );
-	bli_thrinfo_set_sub_node( thread_pc, thread_jc );
-	bli_thrinfo_set_sub_node( thread_pb, thread_pc );
-	bli_thrinfo_set_sub_node( thread_ic, thread_pb );
-	bli_thrinfo_set_sub_node( thread_pa, thread_ic );
-	bli_thrinfo_set_sub_node( thread_jr, thread_pa );
-	bli_thrinfo_set_sub_node( thread_ir, thread_jr );
+	bli_thrinfo_set_sub_node( 0, thread_jc,      root );
+	bli_thrinfo_set_sub_node( 0, thread_pc, thread_jc );
+	bli_thrinfo_set_sub_node( 0, thread_pb, thread_pc );
+	bli_thrinfo_set_sub_node( 0, thread_ic, thread_pb );
+	bli_thrinfo_set_sub_node( 0, thread_pa, thread_ic );
+	bli_thrinfo_set_sub_node( 0, thread_jr, thread_pa );
+	bli_thrinfo_set_sub_node( 0, thread_ir, thread_jr );
 
 	return root;
 }
@@ -232,37 +208,37 @@ void bli_l3_thrinfo_print_gemm_paths
 
 	jc_way  = bli_thrinfo_n_way( jc_info );
 	jc_nt   = bli_thrinfo_num_threads( jc_info );
-	pc_info = bli_thrinfo_sub_node( jc_info );
+	pc_info = bli_thrinfo_sub_node( 0, jc_info );
 
 	if ( !pc_info ) goto print_header;
 
 	pc_way  = bli_thrinfo_n_way( pc_info );
 	pc_nt   = bli_thrinfo_num_threads( pc_info );
-	pb_info = bli_thrinfo_sub_node( pc_info );
+	pb_info = bli_thrinfo_sub_node( 0, pc_info );
 
 	if ( !pb_info ) goto print_header;
 
 	pb_way  = bli_thrinfo_n_way( pb_info );
 	pb_nt   = bli_thrinfo_num_threads( pb_info );
-	ic_info = bli_thrinfo_sub_node( pb_info );
+	ic_info = bli_thrinfo_sub_node( 0, pb_info );
 
 	if ( !ic_info ) goto print_header;
 
 	ic_way  = bli_thrinfo_n_way( ic_info );
 	ic_nt   = bli_thrinfo_num_threads( ic_info );
-	pa_info = bli_thrinfo_sub_node( ic_info );
+	pa_info = bli_thrinfo_sub_node( 0, ic_info );
 
 	if ( !pa_info ) goto print_header;
 
 	pa_way  = bli_thrinfo_n_way( pa_info );
 	pa_nt   = bli_thrinfo_num_threads( pa_info );
-	jr_info = bli_thrinfo_sub_node( pa_info );
+	jr_info = bli_thrinfo_sub_node( 0, pa_info );
 
 	if ( !jr_info ) goto print_header;
 
 	jr_way  = bli_thrinfo_n_way( jr_info );
 	jr_nt   = bli_thrinfo_num_threads( jr_info );
-	ir_info = bli_thrinfo_sub_node( jr_info );
+	ir_info = bli_thrinfo_sub_node( 0, jr_info );
 
 	if ( !ir_info ) goto print_header;
 
@@ -273,21 +249,21 @@ void bli_l3_thrinfo_print_gemm_paths
 
 	printf( "            jc   kc   pb   ic   pa   jr   ir\n" );
 	printf( "xx_nt:    %4ld %4ld %4ld %4ld %4ld %4ld %4ld\n",
-	( unsigned long )jc_nt,
-	( unsigned long )pc_nt,
-	( unsigned long )pb_nt,
-	( unsigned long )ic_nt,
-	( unsigned long )pa_nt,
-	( unsigned long )jr_nt,
-	( unsigned long )ir_nt );
+	        ( unsigned long )jc_nt,
+	        ( unsigned long )pc_nt,
+	        ( unsigned long )pb_nt,
+	        ( unsigned long )ic_nt,
+	        ( unsigned long )pa_nt,
+	        ( unsigned long )jr_nt,
+	        ( unsigned long )ir_nt );
 	printf( "xx_way:   %4ld %4ld %4ld %4ld %4ld %4ld %4ld\n",
-	( unsigned long )jc_way,
-	( unsigned long )pc_way,
-	( unsigned long )pb_way,
-	( unsigned long )ic_way,
-	( unsigned long )pa_way,
-	( unsigned long )jr_way,
-	( unsigned long )ir_way );
+	        ( unsigned long )jc_way,
+	        ( unsigned long )pc_way,
+	        ( unsigned long )pb_way,
+	        ( unsigned long )ic_way,
+	        ( unsigned long )pa_way,
+	        ( unsigned long )jr_way,
+	        ( unsigned long )ir_way );
 	printf( "============================================\n" );
 
 	for ( dim_t gl_id = 0; gl_id < n_threads; ++gl_id )
@@ -304,37 +280,37 @@ void bli_l3_thrinfo_print_gemm_paths
 
 		jc_comm_id = bli_thrinfo_thread_id( jc_info );
 		jc_work_id = bli_thrinfo_work_id( jc_info );
-		pc_info    = bli_thrinfo_sub_node( jc_info );
+		pc_info    = bli_thrinfo_sub_node( 0, jc_info );
 
 		if ( !pc_info ) goto print_thrinfo;
 
 		pc_comm_id = bli_thrinfo_thread_id( pc_info );
 		pc_work_id = bli_thrinfo_work_id( pc_info );
-		pb_info    = bli_thrinfo_sub_node( pc_info );
+		pb_info    = bli_thrinfo_sub_node( 0, pc_info );
 
 		if ( !pb_info ) goto print_thrinfo;
 
 		pb_comm_id = bli_thrinfo_thread_id( pb_info );
 		pb_work_id = bli_thrinfo_work_id( pb_info );
-		ic_info    = bli_thrinfo_sub_node( pb_info );
+		ic_info    = bli_thrinfo_sub_node( 0, pb_info );
 
 		if ( !ic_info ) goto print_thrinfo;
 
 		ic_comm_id = bli_thrinfo_thread_id( ic_info );
 		ic_work_id = bli_thrinfo_work_id( ic_info );
-		pa_info    = bli_thrinfo_sub_node( ic_info );
+		pa_info    = bli_thrinfo_sub_node( 0, ic_info );
 
 		if ( !pa_info ) goto print_thrinfo;
 
 		pa_comm_id = bli_thrinfo_thread_id( pa_info );
 		pa_work_id = bli_thrinfo_work_id( pa_info );
-		jr_info    = bli_thrinfo_sub_node( pa_info );
+		jr_info    = bli_thrinfo_sub_node( 0, pa_info );
 
 		if ( !jr_info ) goto print_thrinfo;
 
 		jr_comm_id = bli_thrinfo_thread_id( jr_info );
 		jr_work_id = bli_thrinfo_work_id( jr_info );
-		ir_info    = bli_thrinfo_sub_node( jr_info );
+		ir_info    = bli_thrinfo_sub_node( 0, jr_info );
 
 		if ( !ir_info ) goto print_thrinfo;
 
@@ -344,21 +320,21 @@ void bli_l3_thrinfo_print_gemm_paths
 		print_thrinfo:
 
 		printf( "comm ids: %4ld %4ld %4ld %4ld %4ld %4ld %4ld\n",
-		( long )jc_comm_id,
-		( long )pc_comm_id,
-		( long )pb_comm_id,
-		( long )ic_comm_id,
-		( long )pa_comm_id,
-		( long )jr_comm_id,
-		( long )ir_comm_id );
+		        ( long )jc_comm_id,
+		        ( long )pc_comm_id,
+		        ( long )pb_comm_id,
+		        ( long )ic_comm_id,
+		        ( long )pa_comm_id,
+		        ( long )jr_comm_id,
+		        ( long )ir_comm_id );
 		printf( "work ids: %4ld %4ld %4ld %4ld %4ld %4ld %4ld\n",
-		( long )jc_work_id,
-		( long )pc_work_id,
-		( long )pb_work_id,
-		( long )ic_work_id,
-		( long )pa_work_id,
-		( long )jr_work_id,
-		( long )ir_work_id );
+		        ( long )jc_work_id,
+		        ( long )pc_work_id,
+		        ( long )pb_work_id,
+		        ( long )ic_work_id,
+		        ( long )pa_work_id,
+		        ( long )jr_work_id,
+		        ( long )ir_work_id );
 		printf( "--------------------------------------------\n" );
 	}
 
@@ -412,26 +388,26 @@ void bli_l3_thrinfo_print_trsm_paths
 
 	jc_way   = bli_thrinfo_n_way( jc_info );
 	jc_nt    = bli_thrinfo_num_threads( jc_info );
-	pc_info  = bli_thrinfo_sub_node( jc_info );
+	pc_info  = bli_thrinfo_sub_node( 0, jc_info );
 
 	if ( !pc_info ) goto print_header;
 
 	pc_way   = bli_thrinfo_n_way( pc_info );
 	pc_nt    = bli_thrinfo_num_threads( pc_info );
-	pb_info  = bli_thrinfo_sub_node( pc_info );
+	pb_info  = bli_thrinfo_sub_node( 0, pc_info );
 
 	if ( !pb_info ) goto print_header;
 
 	pb_way   = bli_thrinfo_n_way( pb_info );
 	pb_nt    = bli_thrinfo_num_threads( pb_info );
-	ic_info  = bli_thrinfo_sub_node( pb_info );
+	ic_info  = bli_thrinfo_sub_node( 0, pb_info );
 
 	if ( !ic_info ) goto print_header;
 
 	ic_way   = bli_thrinfo_n_way( ic_info );
 	ic_nt    = bli_thrinfo_num_threads( ic_info );
-	pa_info  = bli_thrinfo_sub_node( ic_info );
-	pa_info0 = bli_thrinfo_sub_prenode( ic_info );
+	pa_info  = bli_thrinfo_sub_node( 1, ic_info );
+	pa_info0 = bli_thrinfo_sub_node( 0, ic_info );
 
 	// check_header_prenode:
 
@@ -439,13 +415,13 @@ void bli_l3_thrinfo_print_trsm_paths
 
 	pa_way0  = bli_thrinfo_n_way( pa_info0 );
 	pa_nt0   = bli_thrinfo_num_threads( pa_info0 );
-	jr_info0 = bli_thrinfo_sub_node( pa_info0 );
+	jr_info0 = bli_thrinfo_sub_node( 0, pa_info0 );
 
 	if ( !jr_info0 ) goto check_header_node;
 
 	jr_way0  = bli_thrinfo_n_way( jr_info0 );
 	jr_nt0   = bli_thrinfo_num_threads( jr_info0 );
-	ir_info0 = bli_thrinfo_sub_node( jr_info0 );
+	ir_info0 = bli_thrinfo_sub_node( 0, jr_info0 );
 
 	if ( !ir_info0 ) goto check_header_node;
 
@@ -458,13 +434,13 @@ void bli_l3_thrinfo_print_trsm_paths
 
 	pa_way  = bli_thrinfo_n_way( pa_info );
 	pa_nt   = bli_thrinfo_num_threads( pa_info );
-	jr_info = bli_thrinfo_sub_node( pa_info );
+	jr_info = bli_thrinfo_sub_node( 0, pa_info );
 
 	if ( !jr_info ) goto print_header;
 
 	jr_way  = bli_thrinfo_n_way( jr_info );
 	jr_nt   = bli_thrinfo_num_threads( jr_info );
-	ir_info = bli_thrinfo_sub_node( jr_info );
+	ir_info = bli_thrinfo_sub_node( 0, jr_info );
 
 	if ( !ir_info ) goto print_header;
 
@@ -475,21 +451,21 @@ void bli_l3_thrinfo_print_trsm_paths
 
 	printf( "            jc   kc   pb   ic     pa     jr     ir\n" );
 	printf( "xx_nt:    %4ld %4ld %4ld %4ld  %2ld|%2ld  %2ld|%2ld  %2ld|%2ld\n",
-	( long )jc_nt,
-	( long )pc_nt,
-	( long )pb_nt,
-	( long )ic_nt,
-	( long )pa_nt0, ( long )pa_nt,
-	( long )jr_nt0, ( long )jr_nt,
-	( long )ir_nt0, ( long )ir_nt );
+	        ( long )jc_nt,
+	        ( long )pc_nt,
+	        ( long )pb_nt,
+	        ( long )ic_nt,
+	        ( long )pa_nt0, ( long )pa_nt,
+	        ( long )jr_nt0, ( long )jr_nt,
+	        ( long )ir_nt0, ( long )ir_nt );
 	printf( "xx_way:   %4ld %4ld %4ld %4ld  %2ld|%2ld  %2ld|%2ld  %2ld|%2ld\n",
-    ( long )jc_way,
-	( long )pc_way,
-	( long )pb_way,
-	( long )ic_way,
-	( long )pa_way0, ( long )pa_way,
-	( long )jr_way0, ( long )jr_way,
-	( long )ir_way0, ( long )ir_way );
+	        ( long )jc_way,
+	        ( long )pc_way,
+	        ( long )pb_way,
+	        ( long )ic_way,
+	        ( long )pa_way0, ( long )pa_way,
+	        ( long )jr_way0, ( long )jr_way,
+	        ( long )ir_way0, ( long )ir_way );
 	printf( "==================================================\n" );
 
 
@@ -497,7 +473,6 @@ void bli_l3_thrinfo_print_trsm_paths
 	{
 		jc_info = threads[gl_id];
 
-#if 1
 		// NOTE: This cpp branch contains code that is safe to execute
 		// for small problems that are parallelized enough that one or
 		// more threads gets no work.
@@ -514,26 +489,26 @@ void bli_l3_thrinfo_print_trsm_paths
 
 		jc_comm_id = bli_thrinfo_thread_id( jc_info );
 		jc_work_id = bli_thrinfo_work_id( jc_info );
-		pc_info    = bli_thrinfo_sub_node( jc_info );
+		pc_info    = bli_thrinfo_sub_node( 0, jc_info );
 
 		if ( !pc_info ) goto print_thrinfo;
 
 		pc_comm_id = bli_thrinfo_thread_id( pc_info );
 		pc_work_id = bli_thrinfo_work_id( pc_info );
-		pb_info    = bli_thrinfo_sub_node( pc_info );
+		pb_info    = bli_thrinfo_sub_node( 0, pc_info );
 
 		if ( !pb_info ) goto print_thrinfo;
 
 		pb_comm_id = bli_thrinfo_thread_id( pb_info );
 		pb_work_id = bli_thrinfo_work_id( pb_info );
-		ic_info    = bli_thrinfo_sub_node( pb_info );
+		ic_info    = bli_thrinfo_sub_node( 0, pb_info );
 
 		if ( !ic_info ) goto print_thrinfo;
 
 		ic_comm_id = bli_thrinfo_thread_id( ic_info );
 		ic_work_id = bli_thrinfo_work_id( ic_info );
-		pa_info    = bli_thrinfo_sub_node( ic_info );
-		pa_info0   = bli_thrinfo_sub_prenode( ic_info );
+		pa_info    = bli_thrinfo_sub_node( 1, ic_info );
+		pa_info0   = bli_thrinfo_sub_node( 0, ic_info );
 
 		// check_thrinfo_prenode:
 
@@ -541,13 +516,13 @@ void bli_l3_thrinfo_print_trsm_paths
 
 		pa_comm_id0 = bli_thrinfo_thread_id( pa_info0 );
 		pa_work_id0 = bli_thrinfo_work_id( pa_info0 );
-		jr_info0    = bli_thrinfo_sub_node( pa_info0 );
+		jr_info0    = bli_thrinfo_sub_node( 0, pa_info0 );
 
 		if ( !jr_info0 ) goto check_thrinfo_node;
 
 		jr_comm_id0 = bli_thrinfo_thread_id( jr_info0 );
 		jr_work_id0 = bli_thrinfo_work_id( jr_info0 );
-		ir_info0    = bli_thrinfo_sub_node( jr_info0 );
+		ir_info0    = bli_thrinfo_sub_node( 0, jr_info0 );
 
 		if ( !ir_info0 ) goto check_thrinfo_node;
 
@@ -560,13 +535,13 @@ void bli_l3_thrinfo_print_trsm_paths
 
 		pa_comm_id = bli_thrinfo_thread_id( pa_info );
 		pa_work_id = bli_thrinfo_work_id( pa_info );
-		jr_info    = bli_thrinfo_sub_node( pa_info );
+		jr_info    = bli_thrinfo_sub_node( 0, pa_info );
 
 		if ( !jr_info ) goto print_thrinfo;
 
 		jr_comm_id = bli_thrinfo_thread_id( jr_info );
 		jr_work_id = bli_thrinfo_work_id( jr_info );
-		ir_info    = bli_thrinfo_sub_node( jr_info );
+		ir_info    = bli_thrinfo_sub_node( 0, jr_info );
 
 		if ( !ir_info ) goto print_thrinfo;
 
@@ -574,169 +549,25 @@ void bli_l3_thrinfo_print_trsm_paths
 		ir_work_id = bli_thrinfo_work_id( ir_info );
 
 		print_thrinfo:
-#else
-		dim_t jc_comm_id;
-		dim_t pc_comm_id;
-		dim_t pb_comm_id;
-		dim_t ic_comm_id;
-		dim_t pa_comm_id0, pa_comm_id;
-		dim_t jr_comm_id0, jr_comm_id;
-		dim_t ir_comm_id0, ir_comm_id;
-
-		dim_t jc_work_id;
-		dim_t pc_work_id;
-		dim_t pb_work_id;
-		dim_t ic_work_id;
-		dim_t pa_work_id0, pa_work_id;
-		dim_t jr_work_id0, jr_work_id;
-		dim_t ir_work_id0, ir_work_id;
-
-		// NOTE: We must check each thrinfo_t pointer for NULLness. Certain threads
-		// may not fully build their thrinfo_t structures--specifically when the
-		// dimension being parallelized is not large enough for each thread to have
-		// even one unit of work (where as unit is usually a single micropanel's
-		// width, MR or NR).
-		if ( !jc_info )
-		{
-			jc_comm_id = pc_comm_id = pb_comm_id = ic_comm_id = pa_comm_id = jr_comm_id = ir_comm_id = -1;
-			jc_work_id = pc_work_id = pb_work_id = ic_work_id = pa_work_id = jr_work_id = ir_work_id = -1;
-		}
-		else
-		{
-			jc_comm_id = bli_thrinfo_thread_id( jc_info );
-			jc_work_id = bli_thrinfo_work_id( jc_info );
-			pc_info = bli_thrinfo_sub_node( jc_info );
-
-			if ( !pc_info )
-			{
-				pc_comm_id = pb_comm_id = ic_comm_id = pa_comm_id = jr_comm_id = ir_comm_id = -1;
-				pc_work_id = pb_work_id = ic_work_id = pa_work_id = jr_work_id = ir_work_id = -1;
-			}
-			else
-			{
-				pc_comm_id = bli_thrinfo_thread_id( pc_info );
-				pc_work_id = bli_thrinfo_work_id( pc_info );
-				pb_info = bli_thrinfo_sub_node( pc_info );
-
-				if ( !pb_info )
-				{
-					pb_comm_id = ic_comm_id = pa_comm_id = jr_comm_id = ir_comm_id = -1;
-					pb_work_id = ic_work_id = pa_work_id = jr_work_id = ir_work_id = -1;
-				}
-				else
-				{
-					pb_comm_id = bli_thrinfo_thread_id( pb_info );
-					pb_work_id = bli_thrinfo_work_id( pb_info );
-					ic_info = bli_thrinfo_sub_node( pb_info );
-
-					if ( !ic_info )
-					{
-						ic_comm_id = pa_comm_id = jr_comm_id = ir_comm_id = -1;
-						ic_work_id = pa_work_id = jr_work_id = ir_work_id = -1;
-					}
-					else
-					{
-						ic_comm_id = bli_thrinfo_thread_id( ic_info );
-						ic_work_id = bli_thrinfo_work_id( ic_info );
-						pa_info0 = bli_thrinfo_sub_prenode( ic_info );
-						pa_info = bli_thrinfo_sub_node( ic_info );
-
-						// Prenode
-						if ( !pa_info0 )
-						{
-							pa_comm_id0 = jr_comm_id0 = ir_comm_id0 = -1;
-							pa_work_id0 = jr_work_id0 = ir_work_id0 = -1;
-						}
-						else
-						{
-							pa_comm_id0 = bli_thrinfo_thread_id( pa_info0 );
-							pa_work_id0 = bli_thrinfo_work_id( pa_info0 );
-							jr_info0 = bli_thrinfo_sub_node( pa_info0 );
-
-							if ( !jr_info0 )
-							{
-								jr_comm_id0 = ir_comm_id0 = -1;
-								jr_work_id0 = ir_work_id0 = -1;
-							}
-							else
-							{
-								jr_comm_id0 = bli_thrinfo_thread_id( jr_info0 );
-								jr_work_id0 = bli_thrinfo_work_id( jr_info0 );
-								ir_info0 = bli_thrinfo_sub_node( jr_info0 );
-
-								if ( !ir_info0 )
-								{
-									ir_comm_id0 = -1;
-									ir_work_id0 = -1;
-								}
-								else
-								{
-									ir_comm_id0 = bli_thrinfo_thread_id( ir_info0 );
-									ir_work_id0 = bli_thrinfo_work_id( ir_info0 );
-								}
-							}
-						}
-
-						// Main node
-						if ( !pa_info )
-						{
-							pa_comm_id = jr_comm_id = ir_comm_id = -1;
-							pa_work_id = jr_work_id = ir_work_id = -1;
-						}
-						else
-						{
-							pa_comm_id = bli_thrinfo_thread_id( pa_info );
-							pa_work_id = bli_thrinfo_work_id( pa_info );
-							jr_info = bli_thrinfo_sub_node( pa_info );
-
-							if ( !jr_info )
-							{
-								jr_comm_id = ir_comm_id = -1;
-								jr_work_id = ir_work_id = -1;
-							}
-							else
-							{
-								jr_comm_id = bli_thrinfo_thread_id( jr_info );
-								jr_work_id = bli_thrinfo_work_id( jr_info );
-								ir_info = bli_thrinfo_sub_node( jr_info );
-
-								if ( !ir_info )
-								{
-									ir_comm_id = -1;
-									ir_work_id = -1;
-								}
-								else
-								{
-									ir_comm_id = bli_thrinfo_thread_id( ir_info );
-									ir_work_id = bli_thrinfo_work_id( ir_info );
-								}
-							}
-						}
-					}
-				}
-			}
-		}
-#endif
 
 		printf( "comm ids: %4ld %4ld %4ld %4ld  %2ld|%2ld  %2ld|%2ld  %2ld|%2ld\n",
-		( long )jc_comm_id,
-		( long )pc_comm_id,
-		( long )pb_comm_id,
-		( long )ic_comm_id,
-		( long )pa_comm_id0, ( long )pa_comm_id,
-		( long )jr_comm_id0, ( long )jr_comm_id,
-		( long )ir_comm_id0, ( long )ir_comm_id );
+		        ( long )jc_comm_id,
+		        ( long )pc_comm_id,
+		        ( long )pb_comm_id,
+		        ( long )ic_comm_id,
+		        ( long )pa_comm_id0, ( long )pa_comm_id,
+		        ( long )jr_comm_id0, ( long )jr_comm_id,
+		        ( long )ir_comm_id0, ( long )ir_comm_id );
 		printf( "work ids: %4ld %4ld %4ld %4ld  %2ld|%2ld  %2ld|%2ld  %2ld|%2ld\n",
-		( long )jc_work_id,
-		( long )pc_work_id,
-		( long )pb_work_id,
-		( long )ic_work_id,
-		( long )pa_work_id0, ( long )pa_work_id,
-		( long )jr_work_id0, ( long )jr_work_id,
-		( long )ir_work_id0, ( long )ir_work_id );
+		        ( long )jc_work_id,
+		        ( long )pc_work_id,
+		        ( long )pb_work_id,
+		        ( long )ic_work_id,
+		        ( long )pa_work_id0, ( long )pa_work_id,
+		        ( long )jr_work_id0, ( long )jr_work_id,
+		        ( long )ir_work_id0, ( long )ir_work_id );
 		printf( "--------------------------------------------------\n" );
 	}
-
 }
 
 // -----------------------------------------------------------------------------
