@@ -47,7 +47,7 @@ void PASTEMAC(ch,opname) \
        const ctype*     b, \
        const ctype*     beta, \
              ctype*     c, inc_t rs_c, inc_t cs_c, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      ) \
 { \
@@ -57,7 +57,7 @@ void PASTEMAC(ch,opname) \
 \
 	/* Query the context for the function address of the current
 	   datatype's micro-kernel. */ \
-	PASTECH(tname,_ukr_ft) f = bli_cntx_get_l3_vir_ukr_dt( dt, kerid, cntx ); \
+	PASTECH(tname,_ukr_ft) f = bli_cntx_get_ukr_dt( dt, kerid, cntx ); \
 \
 	/* Invoke the typed function for the given datatype. */ \
 	f \
@@ -92,7 +92,7 @@ void PASTEMAC(ch,opname) \
        const ctype*     bx1, \
              ctype*     b11, \
              ctype*     c11, inc_t rs_c, inc_t cs_c, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      ) \
 { \
@@ -102,7 +102,7 @@ void PASTEMAC(ch,opname) \
 \
 	/* Query the context for the function address of the current
 	   datatype's micro-kernel. */ \
-	PASTECH(tname,_ukr_ft) f = bli_cntx_get_l3_vir_ukr_dt( dt, kerid, cntx ); \
+	PASTECH(tname,_ukr_ft) f = bli_cntx_get_ukr_dt( dt, kerid, cntx ); \
 \
 	/* Invoke the typed function for the given datatype. */ \
 	f \
@@ -133,7 +133,7 @@ void PASTEMAC(ch,opname) \
        const ctype*     a, \
              ctype*     b, \
              ctype*     c, inc_t rs_c, inc_t cs_c, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      ) \
 { \
@@ -143,7 +143,7 @@ void PASTEMAC(ch,opname) \
 \
 	/* Query the context for the function address of the current
 	   datatype's micro-kernel. */ \
-	PASTECH(tname,_ukr_ft) f = bli_cntx_get_l3_vir_ukr_dt( dt, kerid, cntx ); \
+	PASTECH(tname,_ukr_ft) f = bli_cntx_get_ukr_dt( dt, kerid, cntx ); \
 \
 	/* Invoke the typed function for the given datatype. */ \
 	f \
