@@ -35,46 +35,6 @@
 
 #include "blis.h"
 
-typedef void (*xpbys_mxn_vft)
-    (
-            dim_t m,
-            dim_t n,
-      const void* x, inc_t rs_x, inc_t cs_x,
-      const void* b,
-            void* y, inc_t rs_y, inc_t cs_y
-    );
-
-#undef  GENTFUNC2
-#define GENTFUNC2(ctypex,ctypey,chx,chy,op) \
-\
-BLIS_INLINE void PASTEMAC2(chx,chy,op) \
-    ( \
-            dim_t m, \
-            dim_t n, \
-      const void* x, inc_t rs_x, inc_t cs_x, \
-      const void* b, \
-            void* y, inc_t rs_y, inc_t cs_y \
-    ) \
-{ \
-	const ctypex* restrict x_cast = x; \
-	const ctypey* restrict b_cast = b; \
-	      ctypey* restrict y_cast = y; \
-\
-	PASTEMAC3(chx,chy,chy,xpbys_mxn) \
-	( \
-	  m, n, \
-	  x_cast, rs_x, cs_x, \
-	  b_cast, \
-	  y_cast, rs_y,  cs_y \
-	); \
-}
-
-INSERT_GENTFUNC2_BASIC(xpbys_mxn_fn);
-INSERT_GENTFUNC2_MIX_DP(xpbys_mxn_fn);
-
-static xpbys_mxn_vft GENARRAY2_ALL(xpbys_mxn, xpbys_mxn_fn);
-
-
 void bli_gemm_ker_var2
      (
        const obj_t*     a,
@@ -85,29 +45,32 @@ void bli_gemm_ker_var2
              thrinfo_t* thread_par
      )
 {
-	      num_t  dt_exec   = bli_obj_exec_dt( c );
-	      num_t  dt_c      = bli_obj_dt( c );
+	const num_t  dt_a      = bli_obj_dt( a );
+	const num_t  dt_b      = bli_obj_dt( b );
+	const num_t  dt_c      = bli_obj_dt( c );
 
 	const pack_t schema_a  = bli_obj_pack_schema( a );
 	const pack_t schema_b  = bli_obj_pack_schema( b );
 
-	      dim_t  m         = bli_obj_length( c );
-	      dim_t  n         = bli_obj_width( c );
-	      dim_t  k         = bli_obj_width( a );
+	const dim_t  m         = bli_obj_length( c );
+	const dim_t  n         = bli_obj_width( c );
+	const dim_t  k         = bli_obj_width( a );
 
 	const char*  a_cast    = bli_obj_buffer_at_off( a );
 	const inc_t  is_a      = bli_obj_imag_stride( a );
-	      dim_t  pd_a      = bli_obj_panel_dim( a );
-	      inc_t  ps_a      = bli_obj_panel_stride( a );
+	const dim_t  pd_a      = bli_obj_panel_dim( a );
+	const inc_t  ps_a      = bli_obj_panel_stride( a );
 
 	const char*  b_cast    = bli_obj_buffer_at_off( b );
 	const inc_t  is_b      = bli_obj_imag_stride( b );
-	      dim_t  pd_b      = bli_obj_panel_dim( b );
-	      inc_t  ps_b      = bli_obj_panel_stride( b );
+	const dim_t  pd_b      = bli_obj_panel_dim( b );
+	const inc_t  ps_b      = bli_obj_panel_stride( b );
 
 	      char*  c_cast    = bli_obj_buffer_at_off( c );
-	      inc_t  rs_c      = bli_obj_row_stride( c );
-	      inc_t  cs_c      = bli_obj_col_stride( c );
+	const inc_t  rs_c      = bli_obj_row_stride( c );
+	const inc_t  cs_c      = bli_obj_col_stride( c );
+	const inc_t  off_m     = bli_obj_row_off( c );
+	const inc_t  off_n     = bli_obj_col_off( c );
 
 	// If any dimension is zero, return immediately.
 	if ( bli_zero_dim3( m, n, k ) ) return;
@@ -123,54 +86,15 @@ void bli_gemm_ker_var2
 
 	// Grab the addresses of the internal scalar buffers for the scalar
 	// merged above and the scalar attached to C.
-	// NOTE: We know that scalar_b is of type dt_exec due to the above code
-	// that casts the scalars of A and B to dt_exec via scalar_a and scalar_b,
+	// NOTE: We know that scalar_b is of type dt_comp due to the above code
+	// that casts the scalars of A and B to dt_comp via scalar_a and scalar_b,
 	// and we know that the internal scalar in C is already of the type dt_c
 	// due to the casting in the implementation of bli_obj_scalar_attach().
 	const char* alpha_cast = bli_obj_internal_scalar_buffer( &scalar_b );
 	const char* beta_cast  = bli_obj_internal_scalar_buffer( c );
 
-#if 1
-	// Under certain conditions, we can avoid the overhead of calling the 1m
-	// virtual microkernel by having the real-domain macrokernel execute with
-	// the real-domain microkernel. (See the function definition for details.)
-	if ( bli_cntx_method( cntx ) == BLIS_1M )
-	{
-		bli_gemm_ind_recast_1m_params
-		(
-		  &dt_exec,
-		  &dt_c,
-		  schema_a,
-		  c,
-		  &m, &n, &k,
-		  &pd_a, &ps_a,
-		  &pd_b, &ps_b,
-		  &rs_c, &cs_c,
-		  cntx
-		);
-	}
-#endif
-
-#ifdef BLIS_ENABLE_GEMM_MD
-	// Tweak parameters in select mixed domain cases (rcc, crc, ccr).
-	if ( bli_cntx_method( cntx ) == BLIS_NAT )
-	{
-		bli_gemm_md_ker_var2_recast
-		(
-		  &dt_exec,
-		  bli_obj_dt( a ),
-		  bli_obj_dt( b ),
-		  &dt_c,
-		  &m, &n, &k,
-		  &pd_a, &ps_a,
-		  &pd_b, &ps_b,
-		  c,
-		  &rs_c, &cs_c
-		);
-	}
-#endif
-
-	const siz_t dt_size   = bli_dt_size( dt_exec );
+	const siz_t dt_a_size = bli_dt_size( dt_a );
+	const siz_t dt_b_size = bli_dt_size( dt_b );
 	const siz_t dt_c_size = bli_dt_size( dt_c );
 
 	// Alias some constants to simpler names.
@@ -179,26 +103,8 @@ void bli_gemm_ker_var2
 
 	// Query the context for the micro-kernel address and cast it to its
 	// function pointer type.
-	gemm_ukr_ft gemm_ukr = bli_cntx_get_l3_vir_ukr_dt( dt_exec, BLIS_GEMM_UKR, cntx );
-
-	// Query the params field from the obj_t. If it is non-NULL, grab the ukr
-	// field of the params struct. If that function pointer is non-NULL, use it
-	// as our microkernel instead of the default microkernel queried from the
-	// cntx above.
-	const gemm_ker_params_t* params = bli_obj_ker_params( c );
-	gemm_ukr_ft user_ukr = params ? params->ukr : NULL;
-	if ( user_ukr ) gemm_ukr = user_ukr;
-
-	// Temporary C buffer for edge cases. Note that the strides of this
-	// temporary buffer are set so that they match the storage of the
-	// original C matrix. For example, if C is column-stored, ct will be
-	// column-stored as well.
-	char        ct[ BLIS_STACK_BUF_MAX_SIZE ]
-	                __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE)));
-	const bool  col_pref    = bli_cntx_ukr_prefers_cols_dt( dt_exec, BLIS_GEMM_VIR_UKR, cntx );
-	const inc_t rs_ct       = ( col_pref ? 1 : NR );
-	const inc_t cs_ct       = ( col_pref ? MR : 1 );
-	const char* zero        = bli_obj_buffer_for_const( dt_exec, &BLIS_ZERO );
+	gemm_ukr_ft gemm_ukr = bli_gemm_var_cntl_ukr( cntl );
+	const void* params   = bli_gemm_var_cntl_params( cntl );
 
 	//
 	// Assumptions/assertions:
@@ -223,9 +129,9 @@ void bli_gemm_ker_var2
 	const dim_t m_left = m % MR;
 
 	// Determine some increments used to step through A, B, and C.
-	const inc_t rstep_a = ps_a * dt_size;
+	const inc_t rstep_a = ps_a * dt_a_size;
 
-	const inc_t cstep_b = ps_b * dt_size;
+	const inc_t cstep_b = ps_b * dt_b_size;
 
 	const inc_t rstep_c = rs_c * MR * dt_c_size;
 	const inc_t cstep_c = cs_c * NR * dt_c_size;
@@ -251,7 +157,7 @@ void bli_gemm_ker_var2
 
 	// Query the number of threads and thread ids for the jr loop around
 	// the microkernel.
-	thrinfo_t* thread = bli_thrinfo_sub_node( thread_par );
+	thrinfo_t* thread = bli_thrinfo_sub_node( 0, thread_par );
 	const dim_t jr_nt  = bli_thrinfo_n_way( thread );
 	const dim_t jr_tid = bli_thrinfo_work_id( thread );
 
@@ -279,16 +185,18 @@ void bli_gemm_ker_var2
 
 	// Query the number of threads and thread ids for the ir loop around
 	// the microkernel.
-	thrinfo_t* thread = bli_thrinfo_sub_node( thread_par );
-	thrinfo_t* caucus = bli_thrinfo_sub_node( thread );
+	thrinfo_t* thread = bli_thrinfo_sub_node( 0, thread_par );
+	thrinfo_t* caucus = bli_thrinfo_sub_node( 0, thread );
+	const dim_t jr_nt  = bli_thrinfo_n_way( thread );
+	const dim_t jr_tid = bli_thrinfo_work_id( thread );
 	const dim_t ir_nt  = bli_thrinfo_n_way( caucus );
 	const dim_t ir_tid = bli_thrinfo_work_id( caucus );
 
 	// Determine the thread range and increment for the 2nd and 1st loops.
 	// NOTE: The definition of bli_thread_range_slrr() will depend on whether
 	// slab or round-robin partitioning was requested at configure-time.
-	bli_thread_range_slrr( thread, n_iter, 1, FALSE, &jr_start, &jr_end, &jr_inc );
-	bli_thread_range_slrr( caucus, m_iter, 1, FALSE, &ir_start, &ir_end, &ir_inc );
+	bli_thread_range_slrr( jr_tid, jr_nt, n_iter, 1, FALSE, &jr_start, &jr_end, &jr_inc );
+	bli_thread_range_slrr( ir_tid, ir_nt, m_iter, 1, FALSE, &ir_start, &ir_end, &ir_inc );
 
 	// Calculate the total number of microtiles assigned to this thread.
 	dim_t n_ut_for_me = ( ( ir_end + ir_inc - 1 - ir_start ) / ir_inc ) *
@@ -340,53 +248,26 @@ void bli_gemm_ker_var2
 			bli_auxinfo_set_next_a( a2, &aux );
 			bli_auxinfo_set_next_b( b2, &aux );
 
-			// Edge case handling now occurs within the microkernel itself, but
-			// we must still explicitly accumulate to a temporary microtile in
-			// situations where a virtual microkernel is being used, such as
-			// during the 1m method or some cases of mixed datatypes.
-			if ( dt_exec == dt_c )
-			{
-				// Invoke the gemm micro-kernel.
-				gemm_ukr
-				(
-				  m_cur,
-				  n_cur,
-				  k,
-				  ( void* )alpha_cast,
-				  ( void* )a1,
-				  ( void* )b1,
-				  ( void* )beta_cast,
-				           c11, rs_c, cs_c,
-				  &aux,
-				  ( cntx_t* )cntx
-				);
-			}
-			else
-			{
-				// Invoke the gemm micro-kernel.
-				gemm_ukr
-				(
-				  MR,
-				  NR,
-				  k,
-				  ( void* )alpha_cast,
-				  ( void* )a1,
-				  ( void* )b1,
-				  ( void* )zero,
-				           &ct, rs_ct, cs_ct,
-				  &aux,
-				  ( cntx_t* )cntx
-				);
+			// Set the current offset into the C matrix in the auxinfo_t
+			// object.
+			bli_auxinfo_set_off_m( off_m + i, &aux );
+			bli_auxinfo_set_off_m( off_n + j, &aux );
 
-				// Accumulate to C with typecasting.
-				xpbys_mxn[ dt_exec ][ dt_c ]
-				(
-				  m_cur, n_cur,
-				  &ct, rs_ct, cs_ct,
-				  ( void* )beta_cast,
-				  c11, rs_c, cs_c
-				);
-			}
+			// Edge case handling now occurs within the microkernel itself.
+			// Invoke the gemm micro-kernel.
+			gemm_ukr
+			(
+			  m_cur,
+			  n_cur,
+			  k,
+			  ( void* )alpha_cast,
+			  ( void* )a1,
+			  ( void* )b1,
+			  ( void* )beta_cast,
+			           c11, rs_c, cs_c,
+			  &aux,
+			  ( cntx_t* )cntx
+			);
 
 			// Decrement the number of microtiles assigned to the thread; once
 			// it reaches zero, return immediately.
