@@ -182,7 +182,7 @@ void PASTEMAC(ch,varname) \
 	ctype           ct[ BLIS_STACK_BUF_MAX_SIZE \
 	                    / sizeof( ctype ) ] \
 	                    __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
-	const bool      col_pref    = bli_cntx_l3_vir_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
+	const bool      col_pref    = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_VIR_UKR, cntx ); \
 	const inc_t     rs_ct       = ( col_pref ? 1 : NR ); \
 	const inc_t     cs_ct       = ( col_pref ? MR : 1 ); \
 \
@@ -349,8 +349,8 @@ void PASTEMAC(ch,varname) \
 	/*thrinfo_t* caucus = bli_thrinfo_sub_node( thread );*/ \
 \
 	/* Query the number of threads and thread ids for each loop. */ \
-	dim_t jr_nt  = bli_thread_n_way( thread ); \
-	dim_t jr_tid = bli_thread_work_id( thread ); \
+	dim_t jr_nt  = bli_thrinfo_n_way( thread ); \
+	dim_t jr_tid = bli_thrinfo_work_id( thread ); \
 \
 	dim_t jr_start, jr_end; \
 	dim_t jr_inc; \
