@@ -110,9 +110,12 @@ err_t bli_check_alignment_is_mult_of_ptr_size( size_t align_size );
 err_t bli_check_object_alias_of( const obj_t* a, const obj_t* b );
 
 err_t bli_check_valid_arch_id( arch_t id );
-err_t bli_check_initialized_gks_cntx( const cntx_t* const * cntx );
+err_t bli_check_initialized_gks_cntx( const cntx_t* cntx );
 
 err_t bli_check_valid_mc_mod_mult( const blksz_t* mc, const blksz_t* mr );
 err_t bli_check_valid_nc_mod_mult( const blksz_t* nc, const blksz_t* nr );
 err_t bli_check_valid_kc_mod_mult( const blksz_t* kc, const blksz_t* kr );
 
+err_t bli_check_valid_mr_even( const blksz_t* mr, const mbool_t* row_pref );
+err_t bli_check_valid_nr_even( const blksz_t* mr, const mbool_t* row_pref );
+
