@@ -39,13 +39,12 @@
 
 struct cntl_s
 {
-	// Basic fields (usually required).
-	opid_t         family;
-	bszid_t        bszid;
-	void_fp        var_func;
-	struct cntl_s* sub_prenode;
-	struct cntl_s* sub_node;
-	void*          params;
+	l3_var_oft var_func;
+	struct
+	{
+		dim_t          ways;
+		struct cntl_s* sub_node;
+	} sub_nodes[ BLIS_MAX_SUB_NODES ];
 };
 typedef struct cntl_s cntl_t;
 */
@@ -53,19 +52,16 @@ typedef struct cntl_s cntl_t;
 
 // -- Control tree prototypes --
 
-BLIS_EXPORT_BLIS cntl_t* bli_cntl_create_node
+BLIS_EXPORT_BLIS void bli_cntl_init_node
      (
-       pool_t* pool,
-       opid_t  family,
-       bszid_t bszid,
        void_fp var_func,
-       void*   params,
-       cntl_t* sub_node
+       cntl_t* cntl
      );
 
-BLIS_EXPORT_BLIS void bli_cntl_free_node
+BLIS_EXPORT_BLIS void bli_cntl_attach_sub_node
      (
-       pool_t* pool,
+       dim_t   ways,
+       cntl_t* sub_node,
        cntl_t* cntl
      );
 
@@ -76,121 +72,45 @@ BLIS_EXPORT_BLIS void bli_cntl_clear_node
 
 // -----------------------------------------------------------------------------
 
-BLIS_EXPORT_BLIS void bli_cntl_free
-     (
-       pool_t* pool,
-       cntl_t* cntl
-     );
-
-BLIS_EXPORT_BLIS cntl_t* bli_cntl_copy
-     (
-             pool_t* pool,
-       const cntl_t* cntl
-     );
-
-BLIS_EXPORT_BLIS void bli_cntl_mark_family
-     (
-       opid_t  family,
-       cntl_t* cntl
-     );
-
-// -----------------------------------------------------------------------------
-
-dim_t bli_cntl_calc_num_threads_in
-     (
-       const rntm_t* rntm,
-       const cntl_t* cntl
-     );
-
-// -----------------------------------------------------------------------------
-
 // cntl_t query (fields only)
 
-BLIS_INLINE opid_t bli_cntl_family( const cntl_t* cntl )
-{
-	return cntl->family;
-}
-
-BLIS_INLINE bszid_t bli_cntl_bszid( const cntl_t* cntl )
-{
-	return cntl->bszid;
-}
-
 BLIS_INLINE void_fp bli_cntl_var_func( const cntl_t* cntl )
 {
 	return cntl->var_func;
 }
 
-BLIS_INLINE cntl_t* bli_cntl_sub_prenode( const cntl_t* cntl )
+BLIS_INLINE dim_t bli_cntl_ways( dim_t which, const cntl_t* cntl )
 {
-	return cntl->sub_prenode;
+	return cntl->sub_nodes[ which ].ways;
 }
 
-BLIS_INLINE cntl_t* bli_cntl_sub_node( const cntl_t* cntl )
+BLIS_INLINE cntl_t* bli_cntl_sub_node( dim_t which, const cntl_t* cntl )
 {
-	return cntl->sub_node;
-}
-
-BLIS_INLINE void* bli_cntl_params( const cntl_t* cntl )
-{
-	return cntl->params;
-}
-
-BLIS_INLINE uint64_t bli_cntl_params_size( const cntl_t* cntl )
-{
-	// The first 64 bytes is always the size of the params structure.
-	return *( ( uint64_t* )(cntl->params) );
+	return cntl->sub_nodes[ which ].sub_node;
 }
 
 // cntl_t query (complex)
 
-BLIS_INLINE bool bli_cntl_is_null( const cntl_t* cntl )
-{
-	return ( bool )
-	       ( cntl == NULL );
-}
-
 BLIS_INLINE bool bli_cntl_is_leaf( const cntl_t* cntl )
 {
 	return ( bool )
-	       ( bli_cntl_sub_node( cntl ) == NULL );
-}
-
-BLIS_INLINE bool bli_cntl_does_part( const cntl_t* cntl )
-{
-	return ( bool )
-	       ( bli_cntl_bszid( cntl ) != BLIS_NO_PART );
+	       ( bli_cntl_sub_node( 0, cntl ) == NULL );
 }
 
 // cntl_t modification
 
-BLIS_INLINE void bli_cntl_set_family( opid_t family, cntl_t* cntl )
-{
-	cntl->family = family;
-}
-
-BLIS_INLINE void bli_cntl_set_bszid( bszid_t bszid, cntl_t* cntl )
-{
-	cntl->bszid = bszid;
-}
-
 BLIS_INLINE void bli_cntl_set_var_func( void_fp var_func, cntl_t* cntl )
 {
 	cntl->var_func = var_func;
 }
 
-BLIS_INLINE void bli_cntl_set_sub_prenode( cntl_t* sub_prenode, cntl_t* cntl )
+BLIS_INLINE void bli_cntl_set_ways( dim_t which, dim_t ways, cntl_t* cntl )
 {
-	cntl->sub_prenode = sub_prenode;
+	cntl->sub_nodes[ which ].ways = ways;
 }
 
-BLIS_INLINE void bli_cntl_set_sub_node( cntl_t* sub_node, cntl_t* cntl )
+BLIS_INLINE void bli_cntl_set_sub_node( dim_t which, cntl_t* sub_node, cntl_t* cntl )
 {
-	cntl->sub_node = sub_node;
-}
-
-BLIS_INLINE void bli_cntl_set_params( void* params, cntl_t* cntl )
-{
-	cntl->params = params;
+	cntl->sub_nodes[ which ].sub_node = sub_node;
 }
 
