@@ -108,18 +108,11 @@ void bli_obj_create_without_buffer
 	bli_obj_set_buffer( NULL, obj );
 	bli_obj_set_dt( dt, obj );
 	bli_obj_set_elem_size( elem_size, obj );
-	bli_obj_set_target_dt( dt, obj );
-	bli_obj_set_exec_dt( dt, obj );
-	bli_obj_set_comp_dt( dt, obj );
+	bli_obj_set_comp_prec( bli_dt_prec( dt ), obj );
 	bli_obj_set_dims( m, n, obj );
 	bli_obj_set_offs( 0, 0, obj );
 	bli_obj_set_diag_offset( 0, obj );
 
-	bli_obj_set_pack_fn( NULL, obj );
-	bli_obj_set_pack_params( NULL, obj );
-	bli_obj_set_ker_fn( NULL, obj );
-	bli_obj_set_ker_params( NULL, obj );
-
 	// Set the internal scalar to 1.0.
 	bli_obj_set_scalar_dt( dt, obj );
 	void* s = bli_obj_internal_scalar_buffer( obj );
@@ -128,12 +121,12 @@ void bli_obj_create_without_buffer
 	// scenarios. Failing to do this can lead to reading uninitialized
 	// memory just before calling the macrokernel (as the internal scalars
 	// for A and B are merged).
-	//if      ( bli_is_float( dt )    ) { bli_sset1s( *(( float*    )s) ); }
-	//else if ( bli_is_double( dt )   ) { bli_dset1s( *(( double*   )s) ); }
-	if      ( bli_is_float( dt )    ) { bli_cset1s( *(( scomplex* )s) ); }
-	else if ( bli_is_double( dt )   ) { bli_zset1s( *(( dcomplex* )s) ); }
-	else if ( bli_is_scomplex( dt ) ) { bli_cset1s( *(( scomplex* )s) ); }
-	else if ( bli_is_dcomplex( dt ) ) { bli_zset1s( *(( dcomplex* )s) ); }
+	//if      ( bli_is_float( dt )    ) { bli_tset1s( s, *(( float*    )s) ); }
+	//else if ( bli_is_double( dt )   ) { bli_tset1s( d, *(( double*   )s) ); }
+	if      ( bli_is_float( dt )    ) { bli_tset1s( c, *(( scomplex* )s) ); }
+	else if ( bli_is_double( dt )   ) { bli_tset1s( z, *(( dcomplex* )s) ); }
+	else if ( bli_is_scomplex( dt ) ) { bli_tset1s( c, *(( scomplex* )s) ); }
+	else if ( bli_is_dcomplex( dt ) ) { bli_tset1s( z, *(( dcomplex* )s) ); }
 }
 
 void bli_obj_alloc_buffer
@@ -319,10 +312,10 @@ void bli_obj_free
 	//temp_z = bli_obj_buffer_for_const( BLIS_DCOMPLEX, obj );
 	//temp_i = bli_obj_buffer_for_const( BLIS_INT,      obj );
 
-	bli_dssets( value, 0.0, *temp_s );
-	bli_ddsets( value, 0.0, *temp_d );
-	bli_dcsets( value, 0.0, *temp_c );
-	bli_dzsets( value, 0.0, *temp_z );
+	bli_tsets( d,s, value, 0.0, *temp_s );
+	bli_tsets( d,d, value, 0.0, *temp_d );
+	bli_tsets( d,c, value, 0.0, *temp_c );
+	bli_tsets( d,z, value, 0.0, *temp_z );
 
 	*temp_i = ( gint_t ) value;
 }
@@ -354,33 +347,33 @@ void bli_obj_free
 
 	buf_a = bli_obj_buffer_at_off( a );
 
-	bli_zzsets( 0.0, 0.0, value );
+	bli_tsets( z,z, 0.0, 0.0, value );
 
 	if ( bli_obj_is_float( a ) )
 	{
-		bli_szcopys( *(( float*    )buf_a), value );
+		bli_tcopys( s,z, *(( float*    )buf_a), value );
 	}
 	else if ( bli_obj_is_double( a ) )
 	{
-		bli_dzcopys( *(( double*   )buf_a), value );
+		bli_tcopys( d,z, *(( double*   )buf_a), value );
 	}
 	else if ( bli_obj_is_scomplex( a ) )
 	{
-		bli_czcopys( *(( scomplex* )buf_a), value );
+		bli_tcopys( c,z, *(( scomplex* )buf_a), value );
 	}
 	else if ( bli_obj_is_dcomplex( a ) )
 	{
-		bli_zzcopys( *(( dcomplex* )buf_a), value );
+		bli_tcopys( z,z, *(( dcomplex* )buf_a), value );
 	}
 	else
 	{
 		bli_check_error_code( BLIS_NOT_YET_IMPLEMENTED );
 	}
 
-	bli_zscopys( value, *temp_s );
-	bli_zdcopys( value, *temp_d );
-	bli_zccopys( value, *temp_c );
-	bli_zzcopys( value, *temp_z );
+	bli_tcopys( z,s, value, *temp_s );
+	bli_tcopys( z,d, value, *temp_d );
+	bli_tcopys( z,c, value, *temp_c );
+	bli_tcopys( z,z, value, *temp_z );
 
 	*temp_i = ( gint_t ) bli_zreal( value );
 }
@@ -559,18 +552,19 @@ const char* bli_dt_string
 dim_t bli_align_dim_to_mult
      (
        dim_t dim,
-       dim_t dim_mult
+       dim_t dim_mult,
+       bool  round_up
      )
 {
 	// We return the dimension unmodified if the multiple is zero
 	// (to avoid division by zero).
 	if ( dim_mult == 0 ) return dim;
 
-	dim = ( ( dim + dim_mult - 1 ) /
-	        dim_mult ) *
-	        dim_mult;
+	if ( round_up )
+		dim += dim_mult - 1;
 
-	return dim;
+	// Avoid rounding down to zero.
+	return bli_max( dim_mult, ( dim / dim_mult ) * dim_mult );
 }
 
 dim_t bli_align_dim_to_size
@@ -664,9 +658,7 @@ void bli_obj_print
 	fprintf( file, " - is complex    %lu\n", ( unsigned long )bli_obj_is_complex( obj ) );
 	fprintf( file, " - is d. prec    %lu\n", ( unsigned long )bli_obj_is_double_prec( obj ) );
 	fprintf( file, " - datatype      %lu\n", ( unsigned long )bli_obj_dt( obj ) );
-	fprintf( file, " - target dt     %lu\n", ( unsigned long )bli_obj_target_dt( obj ) );
-	fprintf( file, " - exec dt       %lu\n", ( unsigned long )bli_obj_exec_dt( obj ) );
-	fprintf( file, " - comp dt       %lu\n", ( unsigned long )bli_obj_comp_dt( obj ) );
+	fprintf( file, " - comp prec     %lu\n", ( unsigned long )bli_obj_comp_prec( obj ) );
 	fprintf( file, " - scalar dt     %lu\n", ( unsigned long )bli_obj_scalar_dt( obj ) );
 	fprintf( file, " - has trans     %lu\n", ( unsigned long )bli_obj_has_trans( obj ) );
 	fprintf( file, " - has conj      %lu\n", ( unsigned long )bli_obj_has_conj( obj ) );
