@@ -60,8 +60,6 @@ void PASTEF77(ch,blasname) \
 	uplo_t  blis_uploc; \
 	trans_t blis_transa; \
 	dim_t   m0, k0; \
-	inc_t   rs_a, cs_a; \
-	inc_t   rs_c, cs_c; \
 \
 	/* Initialize BLIS. */ \
 	bli_init_auto(); \
@@ -93,8 +91,8 @@ void PASTEF77(ch,blasname) \
 	   - the rank-k product is empty (either because alpha is zero or k
 	     is zero) AND matrix C is not scaled. */ \
 	if ( m0 == 0 || \
-	     ( ( PASTEMAC(chr,eq0)( *alpha ) || k0 == 0 ) \
-	       && PASTEMAC(chr,eq1)( *beta ) \
+	     ( ( bli_teq0s( chr, *alpha ) || k0 == 0 ) \
+	       && bli_teq1s( chr, *beta ) \
          ) \
 	   ) \
 	{ \
@@ -105,13 +103,13 @@ void PASTEF77(ch,blasname) \
 	} \
 \
 	/* Set the row and column strides of the matrix operands. */ \
-	rs_a = 1; \
-	cs_a = *lda; \
-	rs_c = 1; \
-	cs_c = *ldc; \
+	const inc_t rs_a = 1; \
+	const inc_t cs_a = *lda; \
+	const inc_t rs_c = 1; \
+	const inc_t cs_c = *ldc; \
 \
 	/* Call BLIS interface. */ \
-	PASTEMAC2(ch,blisname,BLIS_TAPI_EX_SUF) \
+	PASTEMAC(ch,blisname,BLIS_TAPI_EX_SUF) \
 	( \
 	  blis_uploc, \
 	  blis_transa, \
@@ -180,8 +178,8 @@ void PASTEF77(ch,blasname) \
 	   - the rank-k product is empty (either because alpha is zero or k
 	     is zero) AND matrix C is not scaled. */ \
 	if ( m0 == 0 || \
-	     ( ( PASTEMAC(chr,eq0)( *alpha ) || k0 == 0 ) \
-	       && PASTEMAC(chr,eq1)( *beta ) \
+	     ( ( bli_teq0s( chr, *alpha ) || k0 == 0 ) \
+	       && bli_teq1s( chr, *beta ) \
          ) \
 	   ) \
 	{ \
