@@ -37,8 +37,10 @@
 //
 // Prototype BLAS-to-BLIS interfaces.
 //
+#undef  GENTPROT
 #undef  GENTPROTRO
-#define GENTPROTRO( ftype, ch, blasname ) \
+#define GENTPROTRO GENTPROT
+#define GENTPROT( ftype, ch, blasname ) \
 \
 BLIS_EXPORT_BLAS void PASTEF77(ch,blasname) \
      ( \
@@ -51,7 +53,11 @@ BLIS_EXPORT_BLAS void PASTEF77(ch,blasname) \
      );
 
 #ifdef BLIS_ENABLE_BLAS
+#ifdef BLIS_ENABLE_SCALAPACK_COMPAT
 INSERT_GENTPROTRO_BLAS( syr2 )
+#else
+INSERT_GENTPROT_BLAS( syr2 )
+#endif
 #endif
 
 #endif
