@@ -41,102 +41,10 @@
 // -- Context initialization prototypes ----------------------------------------
 //
 
-// -- Intel64 architectures --
-
-#ifdef BLIS_CONFIG_SKX
-CNTX_INIT_PROTS( skx )
-#endif
-#ifdef BLIS_CONFIG_KNL
-CNTX_INIT_PROTS( knl )
-#endif
-#ifdef BLIS_CONFIG_KNC
-CNTX_INIT_PROTS( knc )
-#endif
-#ifdef BLIS_CONFIG_HASWELL
-CNTX_INIT_PROTS( haswell )
-#endif
-#ifdef BLIS_CONFIG_SANDYBRIDGE
-CNTX_INIT_PROTS( sandybridge )
-#endif
-#ifdef BLIS_CONFIG_PENRYN
-CNTX_INIT_PROTS( penryn )
-#endif
-
-// -- AMD64 architectures --
-
-#ifdef BLIS_CONFIG_ZEN3
-CNTX_INIT_PROTS( zen3 )
-#endif
-#ifdef BLIS_CONFIG_ZEN2
-CNTX_INIT_PROTS( zen2 )
-#endif
-#ifdef BLIS_CONFIG_ZEN
-CNTX_INIT_PROTS( zen )
-#endif
-#ifdef BLIS_CONFIG_EXCAVATOR
-CNTX_INIT_PROTS( excavator )
-#endif
-#ifdef BLIS_CONFIG_STEAMROLLER
-CNTX_INIT_PROTS( steamroller )
-#endif
-#ifdef BLIS_CONFIG_PILEDRIVER
-CNTX_INIT_PROTS( piledriver )
-#endif
-#ifdef BLIS_CONFIG_BULLDOZER
-CNTX_INIT_PROTS( bulldozer )
-#endif
-
-// -- ARM architectures --
-
-#ifdef BLIS_CONFIG_ARMSVE
-CNTX_INIT_PROTS( armsve )
-#endif
-#ifdef BLIS_CONFIG_A64FX
-CNTX_INIT_PROTS( a64fx )
-#endif
-#ifdef BLIS_CONFIG_FIRESTORM
-CNTX_INIT_PROTS( firestorm )
-#endif
-#ifdef BLIS_CONFIG_THUNDERX2
-CNTX_INIT_PROTS( thunderx2 )
-#endif
-#ifdef BLIS_CONFIG_CORTEXA57
-CNTX_INIT_PROTS( cortexa57 )
-#endif
-#ifdef BLIS_CONFIG_CORTEXA53
-CNTX_INIT_PROTS( cortexa53 )
-#endif
-#ifdef BLIS_CONFIG_CORTEXA15
-CNTX_INIT_PROTS( cortexa15 )
-#endif
-#ifdef BLIS_CONFIG_CORTEXA9
-CNTX_INIT_PROTS( cortexa9 )
-#endif
-
-// -- IBM Power --
-
-#ifdef BLIS_CONFIG_POWER10
-CNTX_INIT_PROTS( power10 )
-#endif
-#ifdef BLIS_CONFIG_POWER9
-CNTX_INIT_PROTS( power9 )
-#endif
-#ifdef BLIS_CONFIG_POWER7
-CNTX_INIT_PROTS( power7 )
-#endif
-
-// -- IBM BG/Q --
-
-#ifdef BLIS_CONFIG_BGQ
-CNTX_INIT_PROTS( bgq )
-#endif
-
-// -- Generic --
-
-#ifdef BLIS_CONFIG_GENERIC
-CNTX_INIT_PROTS( generic )
-#endif
+#undef GENTCONF
+#define GENTCONF( CONFIG, config ) CNTX_INIT_PROTS( config )
 
+INSERT_GENTCONF
 
 //
 // -- Architecture family-specific headers -------------------------------------
@@ -212,15 +120,24 @@ CNTX_INIT_PROTS( generic )
 
 // -- ARM architectures --
 
+// ARM-SVE
 #ifdef BLIS_FAMILY_ARMSVE
 #include "bli_family_armsve.h"
 #endif
 #ifdef BLIS_FAMILY_A64FX
 #include "bli_family_a64fx.h"
 #endif
+// ARM-NEON (4x128)
+#ifdef BLIS_FAMILY_ALTRAMAX
+#include "bli_family_altramax.h"
+#endif
+#ifdef BLIS_FAMILY_ALTRA
+#include "bli_family_altra.h"
+#endif
 #ifdef BLIS_FAMILY_FIRESTORM
 #include "bli_family_firestorm.h"
 #endif
+// ARM-NEON (2x128)
 #ifdef BLIS_FAMILY_THUNDERX2
 #include "bli_family_thunderx2.h"
 #endif
@@ -230,6 +147,7 @@ CNTX_INIT_PROTS( generic )
 #ifdef BLIS_FAMILY_CORTEXA53
 #include "bli_family_cortexa53.h"
 #endif
+// ARM 32-bit (vintage)
 #ifdef BLIS_FAMILY_CORTEXA15
 #include "bli_family_cortexa15.h"
 #endif
@@ -237,7 +155,12 @@ CNTX_INIT_PROTS( generic )
 #include "bli_family_cortexa9.h"
 #endif
 
-// -- IBM Power --
+// -- IBM Power families --
+#ifdef BLIS_FAMILY_POWER
+#include "bli_family_power.h"
+#endif
+
+// -- IBM Power architectures --
 
 #ifdef BLIS_FAMILY_POWER10
 #include "bli_family_power10.h"
@@ -255,6 +178,12 @@ CNTX_INIT_PROTS( generic )
 #include "bli_family_bgq.h"
 #endif
 
+// -- SiFive families --
+
+#ifdef BLIS_FAMILY_SIFIVE_X280
+#include "bli_family_sifive_x280.h"
+#endif
+
 // -- Generic --
 
 #ifdef BLIS_FAMILY_GENERIC
@@ -337,6 +266,20 @@ CNTX_INIT_PROTS( generic )
 #include "bli_kernels_bgq.h"
 #endif
 
+// -- RISC-V --
+
+#ifdef BLIS_KERNELS_RVI
+#include "bli_kernels_rvi.h"
+#endif
+#ifdef BLIS_KERNELS_RVIV
+#include "bli_kernels_rviv.h"
+#endif
+
+// -- SiFive RISC-V architectures --
+
+#ifdef BLIS_KERNELS_SIFIVE_X280
+#include "bli_kernels_sifive_x280.h"
+#endif
 
 
 #endif
