@@ -51,6 +51,13 @@
 #include <errno.h>
 #include <ctype.h>
 
+#ifdef _MSC_VER
+  #define strncasecmp _strnicmp
+  #define strcasecmp _stricmp
+#else
+  #include <strings.h>
+#endif
+
 // Determine the compiler (hopefully) and define conveniently named macros
 // accordingly.
 #if   defined(__ICC) || defined(__INTEL_COMPILER)
@@ -70,28 +77,32 @@
 #endif
 
 // Determine the target operating system.
-#if defined(_WIN32) || defined(__CYGWIN__)
-  #define BLIS_OS_WINDOWS 1
-#elif defined(__gnu_hurd__)
-  #define BLIS_OS_GNU 1
-#elif defined(__APPLE__) || defined(__MACH__)
-  #define BLIS_OS_OSX 1
-#elif defined(__ANDROID__)
-  #define BLIS_OS_ANDROID 1
-#elif defined(__linux__)
-  #define BLIS_OS_LINUX 1
-#elif defined(__bgq__)
-  #define BLIS_OS_BGQ 1
-#elif defined(__bg__)
-  #define BLIS_OS_BGP 1
-#elif defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || \
-      defined(__bsdi__) || defined(__DragonFly__) || \
-      defined(__FreeBSD_kernel__) || defined(__HAIKU__)
-  #define BLIS_OS_BSD 1
-#elif defined(EMSCRIPTEN)
-  #define BLIS_OS_EMSCRIPTEN
-#else
-  #error "Cannot determine operating system"
+#if defined(BLIS_ENABLE_SYSTEM)
+  #if defined(_WIN32) || defined(__CYGWIN__)
+    #define BLIS_OS_WINDOWS 1
+  #elif defined(__gnu_hurd__)
+    #define BLIS_OS_GNU 1
+  #elif defined(__APPLE__) || defined(__MACH__)
+    #define BLIS_OS_OSX 1
+  #elif defined(__ANDROID__)
+    #define BLIS_OS_ANDROID 1
+  #elif defined(__linux__)
+    #define BLIS_OS_LINUX 1
+  #elif defined(__bgq__)
+    #define BLIS_OS_BGQ 1
+  #elif defined(__bg__)
+    #define BLIS_OS_BGP 1
+  #elif defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || \
+        defined(__bsdi__) || defined(__DragonFly__) || \
+        defined(__FreeBSD_kernel__) || defined(__HAIKU__)
+    #define BLIS_OS_BSD 1
+  #elif defined(EMSCRIPTEN)
+    #define BLIS_OS_EMSCRIPTEN
+  #else
+    #error "Cannot determine operating system"
+  #endif
+#else // #if defined(BLIS_DISABLE_SYSTEM)
+  #define BLIS_OS_NONE
 #endif
 
 // A few changes that may be necessary in Windows environments.
