@@ -125,6 +125,8 @@ extern "C" {
 #include "bli_blksz.h"
 #include "bli_func.h"
 #include "bli_mbool.h"
+#include "bli_stack.h"
+#include "bli_check.h"
 #include "bli_cntx.h"
 #include "bli_rntm.h"
 #include "bli_gks.h"
@@ -137,12 +139,12 @@ extern "C" {
 #include "bli_memsys.h"
 #include "bli_mem.h"
 #include "bli_part.h"
+#include "bli_part_cntl.h"
 #include "bli_prune.h"
 #include "bli_query.h"
 #include "bli_auxinfo.h"
 #include "bli_param_map.h"
 #include "bli_clock.h"
-#include "bli_check.h"
 #include "bli_error.h"
 #include "bli_f2c.h"
 #include "bli_machval.h"
