@@ -67,8 +67,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -109,8 +109,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -153,8 +153,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -202,8 +202,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -248,8 +248,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -292,8 +292,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -339,8 +339,8 @@ void PASTEMAC(opname,EX_SUF) \
 \
 	/* Query a type-specific function pointer, except one that uses
 	   void* for function arguments instead of typed pointers. */ \
-	PASTECH2(opname,BLIS_TAPI_EX_SUF,_vft) f = \
-	PASTEMAC2(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
+	PASTECH(opname,BLIS_TAPI_EX_SUF,_vft) f = \
+	PASTEMAC(opname,BLIS_TAPI_EX_SUF,_qfp)( dt ); \
 \
 	f \
 	( \
@@ -364,7 +364,7 @@ GENFRONT( sumsqv )
 #undef  GENFRONT
 #define GENFRONT( opname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
        const obj_t* chi, \
        const obj_t* psi, \
@@ -395,7 +395,7 @@ void PASTEMAC0(opname) \
 	/* Integer objects are handled separately. */ \
 	if ( bli_is_int( dt ) ) \
 	{ \
-		*is_eq = bli_ieqa( buf_chi, buf_psi ); \
+		*is_eq = bli_ieq( buf_chi, buf_psi ); \
 		return; \
 	} \
 \
@@ -425,7 +425,7 @@ GENFRONT( eqsc )
 #undef  GENFRONT
 #define GENFRONT( opname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
        const obj_t* x, \
        const obj_t* y, \
@@ -472,7 +472,7 @@ GENFRONT( eqv )
 #undef  GENFRONT
 #define GENFRONT( opname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
        const obj_t* x, \
        const obj_t* y, \
@@ -529,7 +529,7 @@ GENFRONT( eqm )
 #undef  GENFRONT
 #define GENFRONT( opname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
        const obj_t* chi, \
        const obj_t* psi, \
@@ -571,15 +571,15 @@ void PASTEMAC0(opname) \
 }
 
 GENFRONT( ltsc )
-GENFRONT( ltesc )
+GENFRONT( lesc )
 GENFRONT( gtsc )
-GENFRONT( gtesc )
+GENFRONT( gesc )
 
 
 #undef  GENFRONT
 #define GENFRONT( opname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
              FILE*  file, \
        const char*  s1, \
@@ -627,7 +627,7 @@ GENFRONT( fprintv )
 #undef  GENFRONT
 #define GENFRONT( opname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
              FILE*  file, \
        const char*  s1, \
@@ -693,7 +693,7 @@ GENFRONT( fprintm )
 #undef  GENFRONT
 #define GENFRONT( opname, varname ) \
 \
-void PASTEMAC0(opname) \
+void PASTEMAC(opname) \
      ( \
        const char*  s1, \
        const obj_t* x, \
@@ -704,7 +704,7 @@ void PASTEMAC0(opname) \
 	bli_init_once(); \
 \
 	/* Invoke the typed function. */ \
-	PASTEMAC0(varname) \
+	PASTEMAC(varname) \
 	( \
 	  stdout, \
 	  s1, \
