@@ -53,7 +53,7 @@ void bli_dgemm_armsve_asm_2vx10_unindexed
        const void*      b, \
        const void*      beta, \
              void*      c, inc_t rs_c0, inc_t cs_c0, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      )
 {
