@@ -64,7 +64,7 @@ void bli_dgemm_bgq_int_8x8
        const void*      b0,
        const void*      beta0,
              void*      c0, inc_t rs_c, inc_t cs_c,
-             auxinfo_t* data,
+       const auxinfo_t* data,
        const cntx_t*    cntx
      )
 {
@@ -234,7 +234,7 @@ void bli_zgemm_bgq_int_4x4
        const void*      b0,
        const void*      beta0,
              void*      c0, inc_t rs_c, inc_t cs_c,
-             auxinfo_t* data,
+       const auxinfo_t* data,
        const cntx_t*    cntx
      )
 {
