@@ -264,8 +264,8 @@ void bli_sgemm_knc_asm_30x16
        const void*      b,
        const void*      beta,
              void*      c, inc_t rs_c, inc_t cs_c,
-             auxinfo_t* data,
-             auxinfo_t* data,
+       const auxinfo_t* data,
+       const auxinfo_t* data,
        const cntx_t*    cntx
      )
 {
