@@ -193,7 +193,7 @@ void bli_dgemm_knl_asm_24x8
        const void*      b,
        const void*      beta,
              void*      c, inc_t rs_c_, inc_t cs_c_,
-             auxinfo_t* data,
+       const auxinfo_t* data,
        const cntx_t*    cntx
      )
 {
