@@ -36,16 +36,14 @@ GEMM_UKR_PROT( float,    s, gemm_knl_asm_24x16 )
 
 GEMM_UKR_PROT( double,   d, gemm_knl_asm_24x8 )
 
-PACKM_KER_PROT( float,    s, packm_knl_asm_24xk )
-PACKM_KER_PROT( float,    s, packm_knl_asm_16xk )
+PACKM_KER_PROT( float,    s, packm_knl_asm_24x16 )
 
-PACKM_KER_PROT( double,   d, packm_knl_asm_24xk )
-PACKM_KER_PROT( double,   d, packm_knl_asm_8xk )
+PACKM_KER_PROT( double,   d, packm_knl_asm_24x8 )
 
 // unused:
 GEMM_UKR_PROT( double,   d, gemm_knl_asm_12x16 )
 GEMM_UKR_PROT( double,   d, gemm_knl_asm_30x8 )
 GEMM_UKR_PROT( double,   d, gemm_knl_asm_8x24 )
 
-PACKM_KER_PROT( double,   d, packm_knl_asm_30xk )
+PACKM_KER_PROT( double,   d, packm_knl_asm_30x8 )
 
