@@ -70,7 +70,7 @@ void bli_i16gemm_power10_mma_8x16
         const void*      b,
         const void*      beta,
               void*      c, inc_t rs_c0, inc_t cs_c0,
-              auxinfo_t* data,
+        const auxinfo_t* data,
         const cntx_t*    cntx
     )
 {
