@@ -46,7 +46,7 @@ void bli_dgemm_sandybridge_int_8x4
        const void*      b0,
        const void*      beta0,
              void*      c0, inc_t rs_c0, inc_t cs_c0,
-             auxinfo_t* data,
+       const auxinfo_t* data,
        const cntx_t*    cntx
      )
 {
