@@ -41,7 +41,7 @@
 #undef  GENTFUNCR
 #define GENTFUNCR( ctype, ctype_r, ch, chr, opname, arch, suf ) \
 \
-void PASTEMAC3(ch,opname,arch,suf) \
+void PASTEMAC(ch,opname,arch,suf) \
      ( \
              dim_t   n, \
        const void*   x0, inc_t incx, \
@@ -64,17 +64,17 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	   the behavior of netlib BLAS's i?amax() routines. */ \
 	if ( bli_zero_dim1( n ) ) \
 	{ \
-		PASTEMAC(i,copys)( *zero_i, *index ); \
+		bli_tcopys( i,i, *zero_i, *index ); \
 		return; \
 	} \
 \
 	/* Initialize the index of the maximum absolute value to zero. */ \
-	PASTEMAC(i,copys)( *zero_i, i_max_l ); \
+	bli_tcopys( i,i, *zero_i, i_max_l ); \
 \
 	/* Initialize the maximum absolute value search candidate with
 	   -1, which is guaranteed to be less than all values we will
 	   compute. */ \
-	PASTEMAC(chr,copys)( *minus_one, abs_chi1_max ); \
+	bli_tcopys( chr,chr, *minus_one, abs_chi1_max ); \
 \
 	if ( incx == 1 ) \
 	{ \
@@ -83,23 +83,23 @@ void PASTEMAC3(ch,opname,arch,suf) \
 		for ( dim_t i = 0; i < n; ++i ) \
 		{ \
 			/* Get the real and imaginary components of chi1. */ \
-			PASTEMAC2(ch,chr,gets)( *chi1, chi1_r, chi1_i ); \
+			bli_tgets( ch,chr, *chi1, chi1_r, chi1_i ); \
 \
 			/* Replace chi1_r and chi1_i with their absolute values. */ \
-			PASTEMAC(chr,abval2s)( chi1_r, chi1_r ); \
-			PASTEMAC(chr,abval2s)( chi1_i, chi1_i ); \
+			bli_tabval2s( chr,chr,chr, chi1_r, chi1_r ); \
+			bli_tabval2s( chr,chr,chr, chi1_i, chi1_i ); \
 \
 			/* Add the real and imaginary absolute values together. */ \
-			PASTEMAC(chr,set0s)( abs_chi1 ); \
-			PASTEMAC(chr,adds)( chi1_r, abs_chi1 ); \
-			PASTEMAC(chr,adds)( chi1_i, abs_chi1 ); \
+			bli_tset0s( chr, abs_chi1 ); \
+			bli_tadds( chr,chr,chr, chi1_r, abs_chi1 ); \
+			bli_tadds( chr,chr,chr, chi1_i, abs_chi1 ); \
 \
 			/* If the absolute value of the current element exceeds that of
 			   the previous largest, save it and its index. If NaN is
 			   encountered, then treat it the same as if it were a valid
 			   value that was smaller than any previously seen. This
 			   behavior mimics that of LAPACK's ?lange(). */ \
-			if ( abs_chi1_max < abs_chi1 || ( bli_isnan( abs_chi1 ) && !bli_isnan( abs_chi1_max ) ) ) \
+			if ( abs_chi1_max < abs_chi1 || ( PASTEMAC(chr,isnan)( abs_chi1 ) && !PASTEMAC(chr,isnan)( abs_chi1_max ) ) ) \
 			{ \
 				abs_chi1_max = abs_chi1; \
 				i_max_l      = i; \
@@ -115,23 +115,23 @@ void PASTEMAC3(ch,opname,arch,suf) \
 			const ctype* restrict chi1 = x + (i  )*incx; \
 \
 			/* Get the real and imaginary components of chi1. */ \
-			PASTEMAC2(ch,chr,gets)( *chi1, chi1_r, chi1_i ); \
+			bli_tgets( ch,chr, *chi1, chi1_r, chi1_i ); \
 \
 			/* Replace chi1_r and chi1_i with their absolute values. */ \
-			PASTEMAC(chr,abval2s)( chi1_r, chi1_r ); \
-			PASTEMAC(chr,abval2s)( chi1_i, chi1_i ); \
+			bli_tabval2s( chr,chr,chr, chi1_r, chi1_r ); \
+			bli_tabval2s( chr,chr,chr, chi1_i, chi1_i ); \
 \
 			/* Add the real and imaginary absolute values together. */ \
-			PASTEMAC(chr,set0s)( abs_chi1 ); \
-			PASTEMAC(chr,adds)( chi1_r, abs_chi1 ); \
-			PASTEMAC(chr,adds)( chi1_i, abs_chi1 ); \
+			bli_tset0s( chr, abs_chi1 ); \
+			bli_tadds( chr,chr,chr, chi1_r, abs_chi1 ); \
+			bli_tadds( chr,chr,chr, chi1_i, abs_chi1 ); \
 \
 			/* If the absolute value of the current element exceeds that of
 			   the previous largest, save it and its index. If NaN is
 			   encountered, then treat it the same as if it were a valid
 			   value that was smaller than any previously seen. This
 			   behavior mimics that of LAPACK's ?lange(). */ \
-			if ( abs_chi1_max < abs_chi1 || ( bli_isnan( abs_chi1 ) && !bli_isnan( abs_chi1_max ) ) ) \
+			if ( abs_chi1_max < abs_chi1 || ( PASTEMAC(chr,isnan)( abs_chi1 ) && !PASTEMAC(chr,isnan)( abs_chi1_max ) ) ) \
 			{ \
 				abs_chi1_max = abs_chi1; \
 				i_max_l      = i; \
@@ -140,7 +140,7 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	} \
 \
 	/* Store the final index to the output variable. */ \
-	PASTEMAC(i,copys)( i_max_l, *index ); \
+	bli_tcopys( i,i, i_max_l, *index ); \
 }
 
 INSERT_GENTFUNCR_BASIC( amaxv, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
