@@ -5,6 +5,7 @@
    libraries.
 
    Copyright (C) 2014, The University of Texas at Austin
+   Copyright (C) 2022-2025, Southern Methodist University
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are
@@ -37,10 +38,10 @@
 // Completely generic gemm ukr implementation which checks MR/NR at
 // runtime. Very slow, but has to be used in certain cases.
 
-#undef  GENTFUNC
-#define GENTFUNC( ctype, ch, opname, arch, suf ) \
+#undef  GENTFUNCR
+#define GENTFUNCR( ctype, ctype_r, ch, chr, opname, arch, suf ) \
 \
-static void PASTEMAC3(ch,opname,arch,suf) \
+static void PASTEMAC(ch,ch,opname,arch,suf) \
      ( \
              dim_t      m, \
              dim_t      n, \
@@ -50,7 +51,7 @@ static void PASTEMAC3(ch,opname,arch,suf) \
        const void*      b0, \
        const void*      beta0, \
              void*      c0, inc_t rs_c, inc_t cs_c, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      ) \
 { \
@@ -80,7 +81,7 @@ static void PASTEMAC3(ch,opname,arch,suf) \
 	/* Initialize the accumulator elements in ab to zero. */ \
 	for ( dim_t i = 0; i < m * n; ++i ) \
 	{ \
-		PASTEMAC(ch,set0s)( *(ab + i) ); \
+		bli_tset0s( ch, *(ab + i) ); \
 	} \
 \
 	/* Perform a series of k rank-1 updates into ab. */ \
@@ -92,13 +93,19 @@ static void PASTEMAC3(ch,opname,arch,suf) \
 		   are typically fully unrolled. */ \
 		for ( dim_t j = 0; j < n; ++j ) \
 		{ \
-			ctype bj = *(b + j*cs_b); \
+			ctype bj; \
+			const ctype_r* b_r = (const ctype_r*)(b + j*cs_b); \
+			const ctype_r* b_i = b_r + cs_b; (void)b_i; \
+			bli_tsets( ch,ch, *b_r, *b_i, bj ); \
 \
 			for ( dim_t i = 0; i < m; ++i ) \
 			{ \
-				ctype ai = *(a + i*rs_a); \
+				ctype ai; \
+				const ctype_r* a_r = (const ctype_r*)(a + i*rs_a); \
+				const ctype_r* a_i = a_r + rs_a; (void)a_i; \
+				bli_tsets( ch,ch, *a_r, *a_i, ai ); \
 \
-				PASTEMAC(ch,dots)( ai, bj, *abij ); \
+				bli_tdots( ch,ch,ch,ch, ai, bj, *abij ); \
 \
 				abij += rs_ab; \
 			} \
@@ -111,15 +118,17 @@ static void PASTEMAC3(ch,opname,arch,suf) \
 	/* Scale the result in ab by alpha. */ \
 	for ( dim_t i = 0; i < m * n; ++i ) \
 	{ \
-		PASTEMAC(ch,scals)( *alpha, *(ab + i) ); \
+		bli_tscals( ch,ch,ch, *alpha, *(ab + i) ); \
 	} \
 \
 	/* If beta is zero, overwrite c with the scaled result in ab. Otherwise,
 	   scale by beta and then add the scaled redult in ab. */ \
-	if ( PASTEMAC(ch,eq0)( *beta ) ) \
+	if ( bli_teq0s( ch, *beta ) ) \
 	{ \
-		PASTEMAC(ch,copys_mxn) \
+		bli_tcopys_mxn \
 		( \
+		  ch, \
+		  ch, \
 		  m, \
 		  n, \
 		  ab, rs_ab, cs_ab, \
@@ -128,8 +137,12 @@ static void PASTEMAC3(ch,opname,arch,suf) \
 	} \
 	else \
 	{ \
-		PASTEMAC(ch,xpbys_mxn) \
+		bli_txpbys_mxn \
 		( \
+		  ch, \
+		  ch, \
+		  ch, \
+		  ch, \
 		  m, \
 		  n, \
 		  ab, rs_ab, cs_ab, \
@@ -139,7 +152,7 @@ static void PASTEMAC3(ch,opname,arch,suf) \
 	} \
 }
 
-INSERT_GENTFUNC_BASIC( gemm_gen, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
+INSERT_GENTFUNCR_BASIC( gemm_gen, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
 
 // An implementation that attempts to facilitate emission of vectorized
 // instructions via constant loop bounds + #pragma omp simd directives.
@@ -149,7 +162,7 @@ INSERT_GENTFUNC_BASIC( gemm_gen, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
 #undef  GENTFUNC
 #define GENTFUNC( ctype, ch, opname, arch, suf ) \
 \
-void PASTEMAC3(ch,opname,arch,suf) \
+void PASTEMAC(ch,ch,opname,arch,suf) \
      ( \
              dim_t      m, \
              dim_t      n, \
@@ -159,7 +172,7 @@ void PASTEMAC3(ch,opname,arch,suf) \
        const void*      b0, \
        const void*      beta0, \
              void*      c0, inc_t rs_c, inc_t cs_c, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      ) \
 { \
@@ -171,14 +184,19 @@ void PASTEMAC3(ch,opname,arch,suf) \
 \
 	const dim_t mr = PASTECH(BLIS_MR_,ch); \
 	const dim_t nr = PASTECH(BLIS_NR_,ch); \
+\
+	const inc_t rs_a   = PASTECH(BLIS_BBM_,ch); \
+	const inc_t cs_a   = PASTECH(BLIS_PACKMR_,ch); \
+	const inc_t rs_b   = PASTECH(BLIS_PACKNR_,ch); \
+	const inc_t cs_b   = PASTECH(BLIS_BBN_,ch); \
 \
 	/* If either BLIS_MR_? or BLIS_NR_? was left undefined by the subconfig,
 	   the compiler can't fully unroll the MR and NR loop iterations below,
 	   which means there's no benefit to using this kernel over a general-
 	   purpose implementation instead. */ \
-	if ( mr == -1 || nr == -1 ) \
+	if ( mr == -1 || nr == -1 || rs_a != 1 || cs_b != 1 ) \
 	{ \
-		PASTEMAC3(ch,gemm_gen,arch,suf) \
+		PASTEMAC(ch,ch,gemm_gen,arch,suf) \
 		( \
 		  m, \
 		  n, \
@@ -194,23 +212,17 @@ void PASTEMAC3(ch,opname,arch,suf) \
 		return; \
 	} \
 \
-	      ctype ab[ BLIS_STACK_BUF_MAX_SIZE \
-	                / sizeof( ctype ) ] \
-	                __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
-	const inc_t rs_ab  = nr; \
-	const inc_t cs_ab  = 1; \
-\
-	const inc_t rs_a   = PASTECH(BLIS_BBM_,ch); \
-	const inc_t cs_a   = PASTECH(BLIS_PACKMR_,ch); \
-	const inc_t rs_b   = PASTECH(BLIS_PACKNR_,ch); \
-	const inc_t cs_b   = PASTECH(BLIS_BBN_,ch); \
+	      char   ab_[ BLIS_STACK_BUF_MAX_SIZE ] __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))) = { 0 }; \
+	      ctype* ab    = (ctype*)ab_; \
+	const inc_t  rs_ab = nr; \
+	const inc_t  cs_ab = 1; \
 \
 \
 	/* Initialize the accumulator elements in ab to zero. */ \
 	PRAGMA_SIMD \
 	for ( dim_t i = 0; i < mr * nr; ++i ) \
 	{ \
-		PASTEMAC(ch,set0s)( ab[ i ] ); \
+		bli_tset0s( ch, ab[ i ] ); \
 	} \
 \
 	/* Perform a series of k rank-1 updates into ab. */ \
@@ -221,8 +233,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
 			PRAGMA_SIMD \
 			for ( dim_t j = 0; j < nr; ++j ) \
 			{ \
-				PASTEMAC(ch,dots) \
+				bli_tdots \
 				( \
+				  ch,ch,ch,ch, \
 				  a[ i*rs_a ], \
 				  b[ j*cs_b ], \
 				  ab[ i*rs_ab + j*cs_ab ]  \
@@ -238,7 +251,7 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	PRAGMA_SIMD \
 	for ( dim_t i = 0; i < mr * nr; ++i ) \
 	{ \
-		PASTEMAC(ch,scals)( *alpha, ab[ i ] ); \
+		bli_tscals( ch,ch,ch, *alpha, ab[ i ] ); \
 	} \
 \
 	/* Output/accumulate intermediate result ab based on the storage
@@ -247,12 +260,13 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	{ \
 		/* C is row-stored. */ \
 \
-		if ( PASTEMAC(ch,eq0)( *beta ) ) \
+		if ( bli_teq0s( ch, *beta ) ) \
 		{ \
 			for ( dim_t i = 0; i < m; ++i ) \
 			for ( dim_t j = 0; j < n; ++j ) \
-			PASTEMAC(ch,copys) \
+			bli_tcopys \
 			( \
+			  ch,ch, \
 			  ab[ i*rs_ab + j*cs_ab ], \
 			  c [ i*rs_c  + j*1     ]  \
 			); \
@@ -261,8 +275,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
 		{ \
 			for ( dim_t i = 0; i < m; ++i ) \
 			for ( dim_t j = 0; j < n; ++j ) \
-			PASTEMAC(ch,xpbys) \
+			bli_txpbys \
 			( \
+			  ch,ch,ch,ch, \
 			  ab[ i*rs_ab + j*cs_ab ], \
 			  *beta, \
 			  c [ i*rs_c  + j*1     ]  \
@@ -273,12 +288,13 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	{ \
 		/* C is column-stored or general-stored. */ \
 \
-		if ( PASTEMAC(ch,eq0)( *beta ) ) \
+		if (bli_teq0s( ch, *beta ) ) \
 		{ \
 			for ( dim_t j = 0; j < n; ++j ) \
 			for ( dim_t i = 0; i < m; ++i ) \
-			PASTEMAC(ch,copys) \
+			bli_tcopys \
 			( \
+			  ch,ch, \
 			  ab[ i*rs_ab + j*cs_ab ], \
 			  c [ i*rs_c  + j*cs_c  ]  \
 			); \
@@ -287,8 +303,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
 		{ \
 			for ( dim_t j = 0; j < n; ++j ) \
 			for ( dim_t i = 0; i < m; ++i ) \
-			PASTEMAC(ch,xpbys) \
+			bli_txpbys \
 			( \
+			  ch,ch,ch,ch, \
 			  ab[ i*rs_ab + j*cs_ab ], \
 			  *beta, \
 			  c [ i*rs_c  + j*cs_c  ]  \
@@ -299,4 +316,72 @@ void PASTEMAC3(ch,opname,arch,suf) \
 
 INSERT_GENTFUNC_BASIC( gemm, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
 
+// Mixed-precision implementation (does not handle mixed-domain cases)
+
+#undef  GENTFUNC2
+#define GENTFUNC2( ctype_ab, ctype_c, chab, chc, opname, arch, suf ) \
+\
+void PASTEMAC(chab,chc,opname,arch,suf) \
+     ( \
+             dim_t      m, \
+             dim_t      n, \
+             dim_t      k, \
+       const void*      alpha, \
+       const void*      a, \
+       const void*      b, \
+       const void*      beta0, \
+             void*      c0, inc_t rs_c, inc_t cs_c, \
+       const auxinfo_t* auxinfo, \
+       const cntx_t*    cntx  \
+     ) \
+{ \
+	const ctype_c*    beta      = beta0; \
+	      ctype_c*    c         = c0; \
+\
+	const cntl_t*     params    = bli_auxinfo_params( auxinfo ); \
+\
+	const gemm_ukr_ft rgemm_ukr = bli_gemm_var_cntl_real_ukr( params ); \
+	const bool        row_pref  = bli_gemm_var_cntl_row_pref( params ); \
+	const void*       params_r  = bli_gemm_var_cntl_real_params( params ); \
+\
+	const dim_t       mr        = bli_gemm_var_cntl_mr( params ); \
+	const dim_t       nr        = bli_gemm_var_cntl_nr( params ); \
+\
+	      ctype_ab    ct[ BLIS_STACK_BUF_MAX_SIZE / sizeof( ctype_ab ) ] \
+	                  __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
+	const inc_t       rs_ct     = row_pref ? nr : 1; \
+	const inc_t       cs_ct     = row_pref ? 1 : mr; \
+\
+	const ctype_ab*   zero      = PASTEMAC(chab,0); \
+\
+	auxinfo_t auxinfo_r = *auxinfo; \
+	bli_auxinfo_set_params( params_r, &auxinfo_r ); \
+\
+	/* ab = alpha * a * b; */ \
+	rgemm_ukr \
+	( \
+	  mr, \
+	  nr, \
+	  k, \
+	  alpha, \
+	  a, \
+	  b, \
+	  zero, \
+	  ct, rs_ct, cs_ct, \
+	  &auxinfo_r, \
+	  cntx  \
+	); \
+\
+	bli_txpbys_mxn \
+	( \
+	  chab,chc,chc,chc, \
+	  m, n, \
+	  ct, rs_ct, cs_ct, \
+	  beta, \
+	  c, rs_c, cs_c \
+	); \
+}
+
+INSERT_GENTFUNC2_MIX_P( gemm, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
+
 
