@@ -40,7 +40,7 @@
 #undef  GENTFUNC
 #define GENTFUNC( ctype, ch, opname, arch, suf, trsmkerid ) \
 \
-void PASTEMAC3(ch,opname,arch,suf) \
+void PASTEMAC(ch,opname,arch,suf) \
      ( \
              dim_t      m, \
              dim_t      n, \
@@ -51,7 +51,7 @@ void PASTEMAC3(ch,opname,arch,suf) \
        const void*      bx10, \
              void*      b110, \
              void*      c110, inc_t rs_c, inc_t cs_c, \
-             auxinfo_t* data, \
+       const auxinfo_t* data, \
        const cntx_t*    cntx  \
      ) \
 { \
@@ -99,7 +99,7 @@ PASTEMAC(d,fprintm)( stdout, "gemmtrsm_ukr: b11", mr, 2*nr, \
 	   circumstances where we would want the gemmtrsm_? operations to have
 	   and exercise their own IO preferences -- I'd have to think about it --
 	   but this doesn't seem to be one of them. */ \
-	const bool      col_pref = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_VIR_UKR, cntx ); \
+	const bool      col_pref = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
 	const inc_t     rs_ct    = ( col_pref ? 1 : nr ); \
 	const inc_t     cs_ct    = ( col_pref ? mr : 1 ); \
 \
@@ -115,6 +115,19 @@ PASTEMAC(d,fprintm)( stdout, "gemmtrsm_ukr: b11", mr, 2*nr, \
 		rs_c_use = rs_ct; \
 		cs_c_use = cs_ct; \
 	} \
+\
+	/* If b11 is stored in broacasted format, the real and imaginary components
+	   will be too widely separated (an imaginary stride > 1). Recompress b11 so
+	   that the imaginary stride is 1 as expected (the duplicated elements aren't needed
+	   here so they are left untouched). */ \
+	if ( cs_b > 1 ) \
+	bli_tcompressbbs_mxn \
+	( \
+	  ch, \
+	  n, \
+	  m, \
+	  b11, cs_b, rs_b  \
+	); \
 \
 	/* lower: b11 = alpha * b11 - a10 * b01; */ \
 	/* upper: b11 = alpha * b11 - a12 * b21; */ \
@@ -138,11 +151,13 @@ PASTEMAC(d,fprintm)( stdout, "gemmtrsm_ukr: b11 after gemm", mr, 2*nr, \
 \
 	/* Broadcast the elements of the updated b11 submatrix to their
 	   duplicated neighbors. */ \
-	PASTEMAC(ch,bcastbbs_mxn) \
+	if ( cs_b > 1 ) \
+	bli_tbcastbbs_mxn \
 	( \
-	  m, \
+	  ch, \
 	  n, \
-	  b11, rs_b, cs_b  \
+	  m, \
+	  b11, cs_b, rs_b  \
 	); \
 \
 	/* b11 = inv(a11) * b11;
@@ -155,6 +170,7 @@ PASTEMAC(d,fprintm)( stdout, "gemmtrsm_ukr: b11 after gemm", mr, 2*nr, \
 	  data, \
 	  cntx  \
 	); \
+	\
 /*
 PASTEMAC(d,fprintm)( stdout, "gemmtrsm_ukr: b11 after trsm", mr, 2*nr, \
                      (double*)b11, rs_b, 1, "%5.2f", "" ); \
@@ -162,8 +178,9 @@ PASTEMAC(d,fprintm)( stdout, "gemmtrsm_ukr: b11 after trsm", mr, 2*nr, \
 \
 	if ( use_ct ) \
 	{ \
-		PASTEMAC(ch,copys_mxn) \
+		bli_tcopys_mxn \
 		( \
+		  ch,ch, \
 		  m, n, \
 		  ct,  rs_ct, cs_ct, \
 		  c11, rs_c,  cs_c  \
