@@ -168,7 +168,7 @@ void libblis_test_hemm_experiment
 	double       time_min  = DBL_MAX;
 	double       time;
 
-	num_t        datatype;
+	num_t        dt_a, dt_b, dt_c, dt_alpha, dt_beta, dt_comp;
 
 	dim_t        m, n;
 	dim_t        mn_side;
@@ -183,7 +183,12 @@ void libblis_test_hemm_experiment
 
 
 	// Use the datatype of the first char in the datatype combination string.
-	bli_param_map_char_to_blis_dt( dc_str[0], &datatype );
+	bli_param_map_char_to_blis_dt( dc_str[0], &dt_c );
+	bli_param_map_char_to_blis_dt( dc_str[1], &dt_a );
+	bli_param_map_char_to_blis_dt( dc_str[2], &dt_b );
+	bli_param_map_char_to_blis_dt( dc_str[3], &dt_alpha );
+	bli_param_map_char_to_blis_dt( dc_str[4], &dt_beta );
+	bli_param_map_char_to_blis_dt( dc_str[5], &dt_comp );
 
 	// Map the dimension specifier to actual dimensions.
 	m = libblis_test_get_dim_from_prob_size( op->dim_spec[0], p_cur );
@@ -196,30 +201,27 @@ void libblis_test_hemm_experiment
 	bli_param_map_char_to_blis_trans( pc_str[3], &transb );
 
 	// Create test scalars.
-	bli_obj_scalar_init_detached( datatype, &alpha );
-	bli_obj_scalar_init_detached( datatype, &beta );
+	bli_obj_scalar_init_detached( dt_alpha, &alpha );
+	bli_obj_scalar_init_detached( dt_beta, &beta );
 
 	// Create test operands (vectors and/or matrices).
 	bli_set_dim_with_side( side, m, n, &mn_side );
-	libblis_test_mobj_create( params, datatype, BLIS_NO_TRANSPOSE,
+	libblis_test_mobj_create( params, dt_a, BLIS_NO_TRANSPOSE,
 	                          sc_str[1], mn_side, mn_side, &a );
-	libblis_test_mobj_create( params, datatype, transb,
+	libblis_test_mobj_create( params, dt_b, transb,
 	                          sc_str[2], m,       n,       &b );
-	libblis_test_mobj_create( params, datatype, BLIS_NO_TRANSPOSE,
+	libblis_test_mobj_create( params, dt_c, BLIS_NO_TRANSPOSE,
 	                          sc_str[0], m,       n,       &c );
-	libblis_test_mobj_create( params, datatype, BLIS_NO_TRANSPOSE,
+	libblis_test_mobj_create( params, dt_c, BLIS_NO_TRANSPOSE,
 	                          sc_str[0], m,       n,       &c_save );
 
+	// Set the computation precision of C.
+	bli_obj_set_comp_prec( bli_dt_prec( dt_comp ), &c );
+
 	// Set alpha and beta.
-	if ( bli_obj_is_real( &c ) )
 	{
-		bli_setsc(  1.2,  0.0, &alpha );
-		bli_setsc( -1.0,  0.0, &beta );
-	}
-	else
-	{
-		bli_setsc(  1.2,  0.8, &alpha );
-		bli_setsc( -1.0,  1.0, &beta );
+		bli_setsc(  2.0,  0.2, &alpha );
+		bli_setsc(  1.2,  0.5, &beta );
 	}
 
 	// Set the structure and uplo properties of A.
@@ -241,7 +243,7 @@ void libblis_test_hemm_experiment
 	bli_obj_set_conj( conja, &a );
 	bli_obj_set_conjtrans( transb, &b );
 
-	// Repeat the experiment n_repeats times and record results. 
+	// Repeat the experiment n_repeats times and record results.
 	for ( i = 0; i < n_repeats; ++i )
 	{
 		bli_copym( &c_save, &c );
@@ -254,8 +256,14 @@ void libblis_test_hemm_experiment
 	}
 
 	// Estimate the performance of the best experiment repeat.
-	*perf = ( 2.0 * mn_side * m * n ) / time_min / FLOPS_PER_UNIT_PERF;
-	if ( bli_obj_is_complex( &c ) ) *perf *= 4.0;
+	if ( bli_is_left( side ) )
+	{
+		*perf = libblis_test_l3_flops( BLIS_HEMM, &a, &b, &c ) / time_min / FLOPS_PER_UNIT_PERF;
+	}
+	else
+	{
+		*perf = libblis_test_l3_flops( BLIS_HEMM, &b, &a, &c ) / time_min / FLOPS_PER_UNIT_PERF;
+	}
 
 	// Perform checks.
 	libblis_test_hemm_check( params, side, &alpha, &a, &b, &beta, &c, &c_save, resid );
@@ -309,11 +317,17 @@ void libblis_test_hemm_check
        double*        resid
      )
 {
-	num_t  dt      = bli_obj_dt( c );
-	num_t  dt_real = bli_obj_dt_proj_to_real( c );
+	uplo_t uploa   = bli_obj_uplo( a );
+	if ( bli_obj_has_trans( a ) )
+		bli_toggle_uplo( &uploa );
+
+	num_t  dt_real = bli_obj_comp_prec( c ) | BLIS_REAL;
+	num_t  dt_comp = bli_obj_comp_prec( c ) | BLIS_COMPLEX;
+	num_t  dt;
 
 	dim_t  m       = bli_obj_length( c );
 	dim_t  n       = bli_obj_width( c );
+	dim_t  mn_side = bli_obj_length( a );
 
 	obj_t  norm;
 	obj_t  t, v, w, z;
@@ -352,6 +366,18 @@ void libblis_test_hemm_check
 	//     = beta * C_orig * t + alpha * transb(B) * w
 	//     = beta * C_orig * t + z
 
+	// Compute our reference checksum in the real domain if all operands
+	// are real, and in the complex domain otherwise.
+	if ( bli_obj_is_real( a ) &&
+	     bli_obj_is_real( b ) &&
+	     bli_obj_is_real( c ) ) dt = dt_real;
+	else                        dt = dt_comp;
+
+	// Project a, b, and c into the appropriate domain and computational
+	// precision, and then proceed with the checking accordingly.
+
+	obj_t a2, b2, c2, c0;
+
 	bli_obj_scalar_init_detached( dt_real, &norm );
 
 	if ( bli_is_left( side ) )
@@ -371,21 +397,42 @@ void libblis_test_hemm_check
 
 	libblis_test_vobj_randomize( params, TRUE, &t );
 
-	bli_gemv( &BLIS_ONE, c, &t, &BLIS_ZERO, &v );
+	// We need to zero out the imaginary part of t in order for our
+	// checks to work in all cases. Otherwise, the imaginary parts
+	// could affect intermediate products, depending on the order that
+	// they are executed.
+	bli_setiv( &BLIS_ZERO, &t );
+
+	// Create type-casted equivalents of a, b, c_orig, and c.
+	bli_obj_create( dt, mn_side, mn_side, 0, 0, &a2 );
+	bli_obj_create( dt, m, n, 0, 0, &b2 );
+	bli_obj_create( dt, m, n, 0, 0, &c2 );
+	bli_obj_create( dt, m, n, 0, 0, &c0 );
+	bli_obj_set_struc( BLIS_HERMITIAN, &a2 );
+	bli_obj_set_uplo( uploa, &a2 );
+
+	// Cast a, b, c_orig, and c into the datatype of our temporary objects.
+	bli_castm( a,      &a2 );
+	bli_castm( b,      &b2 );
+	bli_castm( c_orig, &c2 );
+	bli_castm( c,      &c0 );
+
+	bli_gemv( &BLIS_ONE, &c0, &t, &BLIS_ZERO, &v );
 
 	if ( bli_is_left( side ) )
 	{
-		bli_gemv( &BLIS_ONE, b, &t, &BLIS_ZERO, &w );
-		bli_hemv( alpha, a, &w, &BLIS_ZERO, &z );
+		bli_gemv( &BLIS_ONE, &b2, &t, &BLIS_ZERO, &w );
+		bli_hemv( alpha, &a2, &w, &BLIS_ZERO, &z );
 	}
 	else // else if ( bli_is_right( side ) )
 	{
-		bli_hemv( &BLIS_ONE, a, &t, &BLIS_ZERO, &w );
-		bli_gemv( alpha, b, &w, &BLIS_ZERO, &z );
+		bli_hemv( &BLIS_ONE, &a2, &t, &BLIS_ZERO, &w );
+		bli_gemv( alpha, &b2, &w, &BLIS_ZERO, &z );
 	}
 
-	bli_gemv( beta, c_orig, &t, &BLIS_ONE, &z );
-	
+	bli_gemv( beta, &c2, &t, &BLIS_ONE, &z );
+	if ( bli_obj_is_real( c ) ) bli_setiv( &BLIS_ZERO, &z );
+
 	bli_subv( &z, &v );
 	bli_normfv( &v, &norm );
 	bli_getsc( &norm, resid, &junk );
@@ -394,5 +441,10 @@ void libblis_test_hemm_check
 	bli_obj_free( &v );
 	bli_obj_free( &w );
 	bli_obj_free( &z );
+
+	bli_obj_free( &a2 );
+	bli_obj_free( &b2 );
+	bli_obj_free( &c2 );
+	bli_obj_free( &c0 );
 }
 
