@@ -67,7 +67,7 @@
 #define INPUT_BUFFER_SIZE            256
 #define MAX_FILENAME_LENGTH          1000
 #define MAX_BINARY_NAME_LENGTH       256
-#define MAX_FUNC_STRING_LENGTH       26
+#define MAX_FUNC_STRING_LENGTH       32
 #define FLOPS_PER_UNIT_PERF          1e9
 
 #define MAX_NUM_MSTORAGE             4
@@ -230,6 +230,7 @@ typedef struct test_ops_s
 	test_op_t dotv;
 	test_op_t dotxv;
 	test_op_t normfv;
+	test_op_t invscalv;
 	test_op_t scalv;
 	test_op_t scal2v;
 	test_op_t setv;
@@ -241,6 +242,7 @@ typedef struct test_ops_s
 	test_op_t axpym;
 	test_op_t copym;
 	test_op_t normfm;
+	test_op_t invscalm;
 	test_op_t scalm;
 	test_op_t scal2m;
 	test_op_t setm;
@@ -341,6 +343,7 @@ void libblis_test_read_op_info( test_ops_t*  ops,
 void libblis_test_output_section_overrides( FILE* os, test_ops_t* ops );
 void libblis_test_output_params_struct( FILE* os, test_params_t* params );
 void libblis_test_output_op_struct( FILE* os, test_op_t* op, char* op_str );
+void libblis_test_output_term_tag( void );
 
 // --- Mapping ---
 
@@ -418,7 +421,7 @@ void fill_string_with_n_spaces( char* str, unsigned int n_spaces );
 // --- Create object ---
 
 void libblis_test_mobj_create( test_params_t* params, num_t dt, trans_t trans, char storage, dim_t m, dim_t n, obj_t* a );
-cntl_t* libblis_test_pobj_create( bszid_t bmult_id_m, bszid_t bmult_id_n, invdiag_t inv_diag, pack_t pack_schema, packbuf_t pack_buf, obj_t* a, obj_t* p, cntx_t* cntx, rntm_t* rntm );
+thrinfo_t* libblis_test_pobj_create( bszid_t bmult_id_m, bszid_t bmult_id_n, bszid_t bcast_id_m, invdiag_t inv_diag, pack_t pack_schema, packbuf_t pack_buf, obj_t* a, obj_t* p, cntx_t* cntx );
 void libblis_test_vobj_create( test_params_t* params, num_t dt, char storage, dim_t m, obj_t* x );
 
 // --- Randomize/initialize object ---
@@ -469,6 +472,7 @@ int  libblis_test_l1f_is_disabled( test_op_t* op );
 int  libblis_test_l2_is_disabled( test_op_t* op );
 int  libblis_test_l3ukr_is_disabled( test_op_t* op );
 int  libblis_test_l3_is_disabled( test_op_t* op );
+double libblis_test_l3_flops( opid_t op, obj_t* a, obj_t* b, obj_t* c );
 int  libblis_test_dt_str_has_sp_char( test_params_t* params );
 int  libblis_test_dt_str_has_sp_char_str( int n, char* str );
 int  libblis_test_dt_str_has_dp_char( test_params_t* params );
@@ -504,6 +508,7 @@ char libblis_test_proj_dtchar_to_precchar( char dt_char );
 #include "test_dotv.h"
 #include "test_dotxv.h"
 #include "test_normfv.h"
+#include "test_invscalv.h"
 #include "test_scalv.h"
 #include "test_scal2v.h"
 #include "test_setv.h"
@@ -515,6 +520,7 @@ char libblis_test_proj_dtchar_to_precchar( char dt_char );
 #include "test_axpym.h"
 #include "test_copym.h"
 #include "test_normfm.h"
+#include "test_invscalm.h"
 #include "test_scalm.h"
 #include "test_scal2m.h"
 #include "test_setm.h"
