@@ -179,7 +179,7 @@ void libblis_test_setv_experiment
 	// Randomize x.
 	libblis_test_vobj_randomize( params, FALSE, &x );
 
-	// Repeat the experiment n_repeats times and record results. 
+	// Repeat the experiment n_repeats times and record results.
 	for ( i = 0; i < n_repeats; ++i )
 	{
 		time = bli_clock();
@@ -255,7 +255,7 @@ void libblis_test_setv_check
 		for ( i = 0; i < m_x; ++i )
 		{
 			if ( !bli_seq( *chi1, *beta_cast ) ) { *resid = 1.0; return; }
-			
+
 			chi1 += inc_x;
 		}
 	}
@@ -267,7 +267,7 @@ void libblis_test_setv_check
 		for ( i = 0; i < m_x; ++i )
 		{
 			if ( !bli_deq( *chi1, *beta_cast ) ) { *resid = 1.0; return; }
-			
+
 			chi1 += inc_x;
 		}
 	}
@@ -278,8 +278,8 @@ void libblis_test_setv_check
 
 		for ( i = 0; i < m_x; ++i )
 		{
-			if ( !bli_ceq( *chi1, *beta_cast ) ) { *resid = 1.0; return; }
-			
+			if ( !bli_teqs( c,c,c, *chi1, *beta_cast ) ) { *resid = 1.0; return; }
+
 			chi1 += inc_x;
 		}
 	}
@@ -290,8 +290,8 @@ void libblis_test_setv_check
 
 		for ( i = 0; i < m_x; ++i )
 		{
-			if ( !bli_zeq( *chi1, *beta_cast ) ) { *resid = 1.0; return; }
-			
+			if ( !bli_teqs( z,z,z, *chi1, *beta_cast ) ) { *resid = 1.0; return; }
+
 			chi1 += inc_x;
 		}
 	}
