@@ -166,7 +166,7 @@ void libblis_test_syr2k_experiment
 	double       time_min  = DBL_MAX;
 	double       time;
 
-	num_t        datatype;
+	num_t        dt_a, dt_b, dt_c, dt_alpha, dt_beta, dt_comp;
 
 	dim_t        m, k;
 
@@ -178,7 +178,12 @@ void libblis_test_syr2k_experiment
 
 
 	// Use the datatype of the first char in the datatype combination string.
-	bli_param_map_char_to_blis_dt( dc_str[0], &datatype );
+	bli_param_map_char_to_blis_dt( dc_str[0], &dt_c );
+	bli_param_map_char_to_blis_dt( dc_str[1], &dt_a );
+	bli_param_map_char_to_blis_dt( dc_str[2], &dt_b );
+	bli_param_map_char_to_blis_dt( dc_str[3], &dt_alpha );
+	bli_param_map_char_to_blis_dt( dc_str[4], &dt_beta );
+	bli_param_map_char_to_blis_dt( dc_str[5], &dt_comp );
 
 	// Map the dimension specifier to actual dimensions.
 	m = libblis_test_get_dim_from_prob_size( op->dim_spec[0], p_cur );
@@ -190,31 +195,26 @@ void libblis_test_syr2k_experiment
 	bli_param_map_char_to_blis_trans( pc_str[2], &transb );
 
 	// Create test scalars.
-	bli_obj_scalar_init_detached( datatype, &alpha );
-	bli_obj_scalar_init_detached( datatype, &beta );
+	bli_obj_scalar_init_detached( dt_alpha, &alpha );
+	bli_obj_scalar_init_detached( dt_beta, &beta );
 
 	// Create test operands (vectors and/or matrices).
-	libblis_test_mobj_create( params, datatype, transa,
+	libblis_test_mobj_create( params, dt_a, transa,
 	                          sc_str[1], m, k, &a );
-	libblis_test_mobj_create( params, datatype, transb,
+	libblis_test_mobj_create( params, dt_b, transb,
 	                          sc_str[2], m, k, &b );
-	libblis_test_mobj_create( params, datatype, BLIS_NO_TRANSPOSE,
+	libblis_test_mobj_create( params, dt_c, BLIS_NO_TRANSPOSE,
 	                          sc_str[0], m, m, &c );
-	libblis_test_mobj_create( params, datatype, BLIS_NO_TRANSPOSE,
+	libblis_test_mobj_create( params, dt_c, BLIS_NO_TRANSPOSE,
 	                          sc_str[0], m, m, &c_save );
 
+	// Set the computation precision of C.
+	bli_obj_set_comp_prec( bli_dt_prec( dt_comp ), &c );
+
 	// Set alpha and beta.
-	if ( bli_obj_is_real( &c ) )
 	{
-		bli_setsc(  0.8, 0.0, &alpha );
-		bli_setsc( -1.0, 0.0, &beta );
-	}
-	else
-	{
-		// For syr2k, both alpha and beta may be complex since, unlike her2k,
-		// C is symmetric in both the real and complex cases.
-		bli_setsc(  0.8, 0.5, &alpha );
-		bli_setsc( -1.0, 0.5, &beta );
+		bli_setsc(  2.0,  0.2, &alpha );
+		bli_setsc(  1.2,  0.5, &beta );
 	}
 
 	// Randomize A and B.
@@ -240,7 +240,7 @@ void libblis_test_syr2k_experiment
 	bli_obj_set_conjtrans( transa, &a );
 	bli_obj_set_conjtrans( transb, &b );
 
-	// Repeat the experiment n_repeats times and record results. 
+	// Repeat the experiment n_repeats times and record results.
 	for ( i = 0; i < n_repeats; ++i )
 	{
 		bli_copym( &c_save, &c );
@@ -252,9 +252,11 @@ void libblis_test_syr2k_experiment
 		time_min = bli_clock_min_diff( time_min, time );
 	}
 
+	obj_t bt;
+	bli_obj_alias_with_trans( BLIS_TRANSPOSE, &b, &bt );
+
 	// Estimate the performance of the best experiment repeat.
-	*perf = ( 2.0 * m * m * k ) / time_min / FLOPS_PER_UNIT_PERF;
-	if ( bli_obj_is_complex( &c ) ) *perf *= 4.0;
+	*perf = libblis_test_l3_flops( BLIS_SYR2K, &a, &bt, &c ) / time_min / FLOPS_PER_UNIT_PERF;
 
 	// Perform checks.
 	libblis_test_syr2k_check( params, &alpha, &a, &b, &beta, &c, &c_save, resid );
@@ -306,13 +308,14 @@ void libblis_test_syr2k_check
        double*        resid
      )
 {
-	num_t  dt      = bli_obj_dt( c );
-	num_t  dt_real = bli_obj_dt_proj_to_real( c );
+	uplo_t uploc   = bli_obj_uplo( c );
+	num_t  dt_real = bli_obj_comp_prec( c ) | BLIS_REAL;
+	num_t  dt_comp = bli_obj_comp_prec( c ) | BLIS_COMPLEX;
+	num_t  dt;
 
 	dim_t  m       = bli_obj_length( c );
 	dim_t  k       = bli_obj_width_after_trans( a );
 
-	obj_t  at, bt;
 	obj_t  norm;
 	obj_t  t, v, w1, w2, z;
 
@@ -346,8 +349,17 @@ void libblis_test_syr2k_check
 	//     = beta * C_orig * t + z
 	//
 
-	bli_obj_alias_with_trans( BLIS_TRANSPOSE, a, &at );
-	bli_obj_alias_with_trans( BLIS_TRANSPOSE, b, &bt );
+	// Compute our reference checksum in the real domain if all operands
+	// are real, and in the complex domain otherwise.
+	if ( bli_obj_is_real( a ) &&
+	     bli_obj_is_real( b ) &&
+	     bli_obj_is_real( c ) ) dt = dt_real;
+	else                        dt = dt_comp;
+
+	// Project a, b, and c into the appropriate domain and computational
+	// precision, and then proceed with the checking accordingly.
+
+	obj_t a2, b2, at2, bt2, c2, c0;
 
 	bli_obj_scalar_init_detached( dt_real, &norm );
 
@@ -359,13 +371,39 @@ void libblis_test_syr2k_check
 
 	libblis_test_vobj_randomize( params, TRUE, &t );
 
-	bli_symv( &BLIS_ONE, c, &t, &BLIS_ZERO, &v );
+	// We need to zero out the imaginary part of t in order for our
+	// checks to work in all cases. Otherwise, the imaginary parts
+	// could affect intermediate products, depending on the order that
+	// they are executed.
+	bli_setiv( &BLIS_ZERO, &t );
 
-	bli_gemv( &BLIS_ONE, &at, &t, &BLIS_ZERO, &w2 );
-	bli_gemv( &BLIS_ONE, &bt, &t, &BLIS_ZERO, &w1 );
-	bli_gemv( alpha, a, &w1, &BLIS_ZERO, &z );
-	bli_gemv( alpha, b, &w2, &BLIS_ONE, &z );
-	bli_symv( beta, c_orig, &t, &BLIS_ONE, &z );
+	// Create type-casted equivalents of a, b, c_orig, and c.
+	bli_obj_create( dt, m, k, 0, 0, &a2 );
+	bli_obj_create( dt, k, m, 0, 0, &b2 );
+	bli_obj_create( dt, m, m, 0, 0, &c2 );
+	bli_obj_create( dt, m, m, 0, 0, &c0 );
+	bli_obj_set_struc( BLIS_SYMMETRIC, &c2 );
+	bli_obj_set_struc( BLIS_SYMMETRIC, &c0 );
+	bli_obj_set_uplo( uploc, &c2 );
+	bli_obj_set_uplo( uploc, &c0 );
+
+	// Cast a, b, c_orig, and c into the datatype of our temporary objects.
+	bli_castm( a,      &a2 );
+	bli_castm( b,      &b2 );
+	bli_castm( c_orig, &c2 );
+	bli_castm( c,      &c0 );
+
+	bli_obj_alias_with_trans( BLIS_TRANSPOSE, &a2, &at2 );
+	bli_obj_alias_with_trans( BLIS_TRANSPOSE, &b2, &bt2 );
+
+	bli_symv( &BLIS_ONE, &c0, &t, &BLIS_ZERO, &v );
+
+	bli_gemv( &BLIS_ONE, &at2, &t, &BLIS_ZERO, &w2 );
+	bli_gemv( &BLIS_ONE, &bt2, &t, &BLIS_ZERO, &w1 );
+	bli_gemv( alpha, &a2, &w1, &BLIS_ZERO, &z );
+	bli_gemv( alpha, &b2, &w2, &BLIS_ONE, &z );
+	bli_symv( beta, &c2, &t, &BLIS_ONE, &z );
+	if ( bli_obj_is_real( c ) ) bli_setiv( &BLIS_ZERO, &z );
 
 	bli_subv( &z, &v );
 	bli_normfv( &v, &norm );
@@ -376,5 +414,10 @@ void libblis_test_syr2k_check
 	bli_obj_free( &w1 );
 	bli_obj_free( &w2 );
 	bli_obj_free( &z );
+
+	bli_obj_free( &a2 );
+	bli_obj_free( &b2 );
+	bli_obj_free( &c2 );
+	bli_obj_free( &c0 );
 }
 
